## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: De_DE.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/De_DE.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::De_DE;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<De_DE> hyphenation pattern class

The data for this library is copied from the OpenOffice.org project and
modified to be used as a Perl module by Roland van Ipenburg.

L<http://svn.services.openoffice.org/ooo/trunk/dictionaries/de_DE/>

	Hyphenation dictionary
	----------------------

	Language: German (de DE).
	Origin:   Based on the TeX hyphenation tables
			  http://www.tug.org/tex-archive/language/hyphenation/dehyphn.tex
	License:  GNU LGPL license.
	Author:   conversion author is Marco Huggenberger<marco@by-night.ch>
			  revised conversion and extensions: Daniel Naber
			  http://qa.openoffice.org/issues/show_bug.cgi?id=26355
	Please note, this dictionary is based on syllable matching patterns
	and thus should be suitable under other variations of German

	HYPH de DE hyph_de_DE
	HYPH de CH hyph_de_CH

	--------------------------------------------------------------------------------
	Trennmuster (hyph_de_DE.dic):
	--------------------------------------------------------------------------------

	Die Trennmuster (hyph_de_DE.dic) basieren auf den TeX Trennmustern
	"dehyphn.tex", revision level 31.
	Lizenz der Trennmuster: GNU LGPL. Die Anpassung der Trennmuster an
	den in OpenOffice.org benutzten "ALTLinux LibHnj Hyphenator" wurde
	mit dem Script substrings.pl durchgeführt, das unter
	http://lingucomponent.openoffice.org/hyphenator.html als Teil der
	Datei altlinux_Hyph.zip heruntergeladen werden kann.
	Die Original-Trennmuster können hier heruntergeladen werden:
	http://www.tug.org/tex-archive/language/hyphenation/dehyphn.tex

=cut

__DATA__
ISO8859-1
.aa6l
.6a1ba
.ab3a4s
.a1be
.ab3ei
.a1bi2
.ab3it
.a1b1l8
.a1b1r
.a1b3u
.a1d
.a1do
.ad3o4r
.a2l1t
.alti6
.a3na3c
.an5a2l1g
.a1n1e
.an2gs
.ang8s2t1
.a6n1s
.ap1p
.a2r1s
.ar6sc
.a2r1t
.ar6ta
.8ar6tei
.as2z
.au2f1
.au2s3
.1be
.be5er1b
.be3na
.be2r1t
.ber6t5r6
.1bi
.b6ie
.bie6r5
.bi2ms
.bim6s5t
.1br
.brot3
.br6u6s
.c8h6
.1che6f5
.1da8c
.da2r
.d2a1ri
.dar5in
.da1r5u
.1de
.den6ka
.de1re
.de5r6en
.de1sp2
.des6pe
.de8s2p2o
.de3s1z
.1di
.dia3s4
.dien4
.dy2s1
.e6hr
.eh1re
.ehre6n5
.ei1ne6
.ei6n5eh
.ei8nen
.ei6ns
.ein5sa
.e2n1d
.en1de
.en6der
.en6d5r4
.en3k4
.en8ta8
.en1te
.en8tei
.en4t3r6
.e1p2o1
.er1b
.er1ba
.er6ban
.er1be
.er6b5ei
.erbl8
.er6bla
.e8rd
.er1du
.er6d5um
.e1re
.2er3ei
.e1r5er
.2e1ri
.er3in
.er3o4b
.er1w
.erwi5s
.e1s1p2
.e2s8t1l
.es8t1n
.ex1a2
.ex3em
.fa2ls
.fal6sc
.1fe
.fe6s1t5a
.flu4g3
.1fu
.furc8h8
.1ga
.ga1ne
.ga6ner
.1ge
.ge3n4a
.ge5rö8
.ge1s6
.ha2lb5
.hal1be6
.hal6br
.haup4
.hau4t
.hei1ma6
.he4r3e
.her6za
.he5x
.hin3
.hi2r1s
.hir8sc
.ho4c
.hu3sa
.hy5o
.i1be5
.i1ma
.ima6ge
.in1
.i1ni6
.isc8h
.i1s5chi
.ja6gd5
.1ka
.ka6l1k
.kal6k5o
.ka6ph
.ki4e
.1k2o
.kop6f3
.1kr8
.kraf6
.1kü
.kü5ra
.la2b1b
.lab6br
.1li
.l8i1i
.liie6
.lo6s5k2
.1lös
.lö4s3t
.1ma
.ma5d2
.1mi
.mi2t1
.no6th
.no1to
.no6top
.o1be
.ob2e8ri
.o1b1l8
.o8bs2
.ob6s1t5e
.or3c
.o2r1t
.or2ts
.ort6s5e
.o1st3a
.os1te
.oste8r
.1pe
.p8er
.pe4re6
.pe3t2s
.1ph6
.1p2o
.po8str6
.r6au4m3
.re5an
.ro8q
.ru5the
.rü5b6e2
.sc8h8
.1se
.se6e
.se5n6h
.se5ra
.1si
.si2e
.sp2
.1spi
.spi1k
.spi6ke
.st4
.1sy
.sy2n1
.1tag
.ta1ge
.tage4s5
.tan6kl8
.ta8th
.te6e
.te8str6
.to1d
.to1de4
.to6der
.t8o1ni
.to8nin
.to6we
.um1
.u2mp
.umpf4
.un1
.u1ne6
.un1ge
.ung8e5n
.ur1c
.u1re
.ur5en
.1ve
.ver1
.v2e1ri
.ve6rin
.v2or1
.vora8
.1wah
.wah6l5
.1weg
.we1ge
.we8ge1s
.we8s2t
.wes3te
.wo6r
.wor3a
.wu6n4s
.1zi
.zi4e
.1zu
.z2uc
.zuc8h8
.ä2n1d
.än1de
.ände8re
.öc8h8
aa1c
aa2gr4
aa1l5e
aa6r5a
aa2r1t
a5arti
aa2s1t
aa2t2s
6a1ba
ab3a2r1t
a2b1d
1abdr4
a1be
6ab8el
abe2n1d
aben6dr4
ab5e6rk
ab5e2r1r
ab5e2s1se
1a2b1f8
1a2b1g2
a2b1h
1abhä
a1bi
ab1ir
a2b1k2
1ab1k2o
a1bl8
ab1la
5a6blag
a6bl8aß
ab4ler
a1b1lu
a8blä
5a6blö
a2b1m
ab1ma
abma5c
1a2b1n
a1br
ab1ra
ab1re
5a6brec
ab1ro
a8b1s
ab8s1k2
abs2z
a2b1t
3abtei
a1bu
ab1ur
1a2b1w
a8b1z
5ab1ze
5ab1zu
a1bä
ab1än
abäu8
a1ce
a4ce.
ac8h
a5chal
ach5a2r1t
ach5au
a1che
a8chent
ach6er.
a6ch5er1f
a1chi
ach1l6
a6ch3m
a2ch5n6
a1cho
ac6hr
ach3re
a1chu
a8ch1w
a1chy
ach5äf
ac2k
ac1k2o
a2c2ks
acks6t8
ack5sta
a1d
8ad.
a6d5ac
ad3ant
ad8ar
a2d1d
5ad1di
a1de
a8dein
ade5o8
a1di
adi5en
1ad1j
a2d1l
1adle
a1do
ad1op
adr4
a2dre
3adres
a2dt1
1a2d1v
a6dä
a1e2d
ae1r
a1er.
1aero
8afa
a3fal
af1an
a5far
a5fat
af1au
a1fe
a6fen2t1l
a2f1ex1
a2ff
af1fr6
afr6
af5rau
af1re
1afri
a2ft
af1te
af6tent
af1tr6
af6tra
aft5re
a1fu
a6f5um
8a1fä
a1ga
ag5a1be
a1ge
5a4gent
ag8er
age1s
age1s5e
a2g1g
1ag1gr4
a1g5las
ag1lo
a1gn8
ag2ne
a1go
1a2g8o1g
a1gu
a6g5u2n1d
a1ha
a1he
a2h5ein
a4h3er1h8
a1hi
ahl1a
ah1le
ah1ma
ah4m3ar
ahn1a
a5ho
a6hr
ahra6
ahr5ab
ah1re
ah8rei
ahre6n8s
ahre4s3
ah2r1t
ahr8ti
ah1ru
a1hu
ah8ö
ai1d
ai3d2s
ai1e
a2if6
ai6ns
a3in1se
ai1re
ai4re.
aisc8h
a5i8s2ch.
ai1s8e
ai2s1m
a3ismu
ais6n
ai1so6
a1j
a1ka
1aka1d
a4ka1de
a1ke
a1ki
a2k1k2
1ak1k2o
a1kr8
5akro1
a5lal
al5a6ns
3al8a6r1m
a2lb
al1be
al8be1b
al8ber1w
albl8
alb5la
al1bu
3album
a8l1c
a1le
ale1b
a6l5e6be
a4l3ein
a8lel
a1ler
a8ler1b
a8ler1h8
a6le2r1t
5a6l5eth
a2l1g
1al1gi
al4g1li
a1li
a2l3int
a6ll
al1la
al4lab
al8lan
al4l3ar
al1le
alle3g
a1lo
a4l5ob
a2ls
al1sc
alsc8h
al6s6ch2m
a2l1t
al4the
altr6
al4t3re
8a1lu
al6u5i
a6lur
alu3ta
a1lä
a1ma
a6ma1te
a1me
8ame.
5a6mei1se
a2m1m
am1me
am6m5ei
am6mum
am2n8
a2mp
ampf3a6
a2ms
am1sc
amsc8h
am6s8chw
a2m1t
am2ta
a1mu
a1mä
a3na2c
a1na1d
ana1di
anadi5e
an3a1k2o
an3a6l1p
3a8na1ly
an3a1me
an3a2ra
a1nas
an5as1ti
a1nat
ana2t5s
a2n1d
an1de
an8dent
ande4s3
a1ne
a2n1ec
a8n5eis
an1e2k
4aner.
a6n5e8rd
a8ner1f
ane6rk
a6n5er1ke
an1f
1anfa
an1fe
5anfe2r1t
1an1fä
an1ga
3angab
an1ge
ange1b
5ange1bo
an3g1li
ang6lis
an2gn8
an1gr4
3angri
an2g5t6
an1h
5anhä
a1ni
ani5g
an6i1k
ani4ka
an2io
an5i8on
an1kl8
an1k2n8
an6kno
an1kr8
an4kro
1an5l6
an1m
an1ma
anma5c
anmar4
an1na
3an1n2ah
an1ne
anne4s3
a1no
5a6n1o2d
5a6n3o1ma
5a6no8rd
1an1r
a6ns
an1sa
an1sc
ansc8h
5anschl6
an1so
an4so1z
an1st
an1sta
5anstal
an1s2z
an1te
5antenn
an1th
a8n1w
5anwä
a5ny
an1ze
an4z3e1d
5anzeig
an1zi
5anzieh
an1zu
3anzug
an1ä
5anäs
a1nö
anö8d
a1os
a1pa
ap1fe
3apfel
a1ph
a2ph1t2
aph5ä6
a1pi
8apl8
a1p2o
apo1c
apo1s
a6pos2t
a6po1th
1ap1pa
ap1pr6
a1pr6
a5pä
a3pü
a1ra
a4r3af
a2r3a6ll
ar1b
ar1be
3arbei
2ar2b1t
ar1c
2a1re
ar3ein
a8r1g
ar2gl
2a1ri
ar2ie
ari5es
a6rk
ar1ke
ar8ke2r1s
ar1l
ar6les
a2rn
ar1na
ar4nan
ar5o6c8h
ar1o2d
a1rol
ar2on
ar3ony
a8ror
a3ros
ar5ox
a2r1s
arsc8h
ar6schl6
a2r1t
8ar5tei
artr6
ar6t5ri
a1ru
a1ry
1ar2z1t
arz1w8
ar8zä
arä8m
arö6
ar5öm
ar1ü2
a1sa
asc8h
a1sche
a6schec
asch5l6
as6ch3m
a6s2chn6
as1h
a3s4hi
asp2
as1pa
asp5l8
as1te
as5te1v
1a2sth
a1str6
ast3re
8a1ta
ata5c
ata3la
a6tapf
at8a5pl8
a1te
a6te1li
aten5a
ate5ran
6a2t1f2
6a2t1g2
a1th
ath6a
at3hal
1a2th1l
2a1ti
a2t1l
atl8a
5atlant
3atlas
a2t1m8
8atmus
6a2t1n
a1to
a6t5ops
ato6ra
ato2r1t
a6t5ort.
4a1tr6
a6t5ru
a2t1t
at2t1h
at5t6hä
6a1tu
a2tz
atz1w8
a1tä
a1tü
au1a
au1br
au6bre
a2uc
auc8h
auch3a
au1e
aue4l
au1fe
5au4f3ent
au2ff
3auf1fü
au2f1g2
3auf1ga
1au2f1n
au2f1t
3auf1tr6
1au2f1w
au1ge
3auge.
a6uk
au1kl8
au4kle
au1le
aule8s
6aum
au1ma
au8mar
au2m5p
1au2s1b2
3au2s1d
1au2s1f2
1au2s3g2
au1si
au8sin
au4sta
1au2s1w
1aus1z
au1te
aut5eng
au1th
1au1to
au1ße8
a1v
a1ve
aver1
ave5r6a
av2e1r6i
a1w
a6wes
a1x
a1xi
a2xia
a6x2io
a1ya
a1z
a1zi
azi5er.
8aß
1ba
ba1d
ba1de
8ba8del
ba1la
ba1na
ban6k5r8
ba5ot
ba8rd
bar1di
bardi6n
ba1ro
bas1te
basten6
bau3sp2
2b1b
bbl8
bb6le
b2b1li
2b1c
2b1d
1be
be1a
be8at.
be1c8h
8be2cht
bec2k
8be1cke.
be5el
be1en
bee3r4e
be2e8rei
be5e1ta
be1f2
8be2ff
be1g2
be1hö8
bei1s
bei1se
6b5eisen
bei3tr6
b8el
b4e1l8o
be1lu
belu3t2
be3na2c
be2n1d
ben1d6o
be1ne
be6n5e2r1s
be6n5er1w
be1no
be4nor
be6ns
ben4se6
bens5el
be1nä
be1nü
be1o2
b8er.
be1ra
be8rac
be8r1g
ber1ga
ber8gab.
be2r1r
be1rü
be1s8c
be1se
bes5er1h8
be1s2p2
be5th6a
be2ts
bet5sc
be1un
be1ur
8bex
be1z
bezw8
be6zwec
2b1f8
2b1g2
b1ga
bga2s5
b1ge1
2b1h
bho1le6
1bi
bi1bl8
b6ie
bi1el
b2il
bi1la
bi1lä5
bi1na
bi1no
bi4no1k
bi6stu
bi5tr6
bi2t1t
bit4t5r6
b1j
2b1k2
b1kü6
bl8
b6la.
6b1la1d
6blag
8blam
1blat
b8la2t1t
3blau.
b6la1v
3ble.
b1le1b
b1le1d
8b1leg
8b1leh
8blei1d
8bleih
6b3lein
bl4e4m3o2
b1li
4blic8h
b4li2n1d
8bling
b2l2io
5blit
b4li2tz
b1loh
8b1los
1blu
5blum
2b1lun
blut3a
blu2ts
blut5sc
3blä
blä6s5c
5blö
3blü
blü8sc
2b1m
2b1n
1bo
bo1c8h
bo1d
bo5d6s
boe5
8bo2ff
8bon1k
bo1ra
b1o2r1t
2b1p2
b1q
1br
bra2il6
brast8
bre4a
b5re1d
8bre1f
br2ie
8b5riem
b1r2ig
b6ri1ga
bro1s
b1rup
b2ruz
8bröh
brö2s5c
8bs
b1sa
b8sang
b2s1ar
b1sc
b1se
bs3er1l
bs3erz
b1so
b8sof
b1s2p2
b2st1h
bstr6
b3stru
b5stä
b1su
b6sun
2b1t
b2t1h
1bu
b6ui
bu1ie
bu6l6k
b8u1re
bu1si
bu6sin
6b1v
2b1w
1by1
by1t
by6te.
8b1z
1bä
b5ä6s5
1bü
bü1b6e2
b3ü4ber1
b6ü5be1re
bü1ge6
büge1l5e
bü2r1s
bür6sc
1ca
cag6
ca5la
c2a6re
ca5y
c1c
1ce
ce1li
celi4c
celic8h5
ce1ro
c8h
2ch.
1c8hae
ch1ah
ch3a2k1t
cha1me
cha6mer
8c6hanz
5cha1ra
3ch2a1ri
5cha1to
6ch1b2
1che1f
6chei
ch3e2il
ch3eis
che6rk
6cher1kl8
6ch1f2
4ch1h
5chia1d
5chias
6chi6ns
8ch1j
chl6
5ch4lor
6ch2m
2chn6
ch1ni
ch8n6ie
5cho.
8chob
c2hoi
choi8d
6ch1p
c6hr
ch3ren
ch6res
ch3rü
2chs
2cht
cht5h6a
cht3hi
5chth2on
ch1ti
ch6tin
6chuh
chu4la
6ch3unt
chu2t6t
8chw
1ci
ci5tr6
c2k
2ck.
ck1ei
4c2k1h
ck3l8
ck3n8
c1k2o
ck5o8f
c1k1r8
2c2ks
ckst8
ckstr6
ck5stra
ck6s5u
c2l
1c8o
con6ne
8cor1b
cos6t
c3q
1c6r
8c1t
1cu
1cy
5cä1
cö5
1da.
8daas
2d1a2b1g2
8da1br
6da2b1t
6d1a2b1w
1dac
da2gr4
6d5a6l1k
8d5a2m1t
dan1c
dan1ce
dan6ce.
da1ni
dan6ie
dani5er
dan1ke
dan8ker
2d1an5l6
danla6
6da6ns
8dan1zi
6dan1zu
d1ap
da2r1a8
2d1ar1b
d3ar1c
da6r1m
dar1me
dar6men
4d3a2r1t
8darz
1dat
8da2t1m8
2d1auf
2d1aus
2d1b
2d1c
2d1d
d5de
d3d2h
d1dä
ddä2m1m
ddäm1me8
1de
2deal
de5an
dec8h
de3cha
de1e
de1f
de1fe6
6de2ff
2d1e6hr
5d4eic
de5isc
de1la
de8lar
de2ls
del6s5e
del1sp2
del6spr6
de1ma
de4mag
de1mu
de8mun
de1ne
de8nep
dene6r
den1ge
8denge.
8deng8en
de5o6d
2deol
de5ram
de8rd
8der2d1b
de1re
d2erei
der5ein
de1ro
de2r1r
d8e2r1s
d2e1ru
der5um
de1sa
de4s3am
de4s3an
de4sau
de1si
de6s2il
de4sin
de1so
de8sor
de1sp2
de4spr6
de2su
8deul
de5us.
2d1f
df2l
2d1g
2d1h
1di
dia5c
di5a1ra
di1ce5
dic8h
di3c6hr
di5ena
di1gn8
d2il
di1la
di2l8s
di1na
8di2n1d
6din1f
4d3in1h
2d1i6ns
d2io
di5o6d
d2ip
di3p4t
di1se
di8sen
dis1p2
dis1pe
di5s8p8er
di6s5to
dis3tr6
di1ta
di8tan
di1ti
di8tin
d1j
6dje
2dju
2d1k
2d1l
2d1m
2d1n6
d1ni6
dn1j
dnje6
1do
6d5o1be
do6ber1f
6d5ony
do3ran
6do8rd
2d1o8r1g
do2r1t
dor4t3h
6do1th
do2t1t
dott8e
2d1p
d5q
dr4
1drah
8drak
d5r6a2n1d
6d1re.
4drec8h
d6rec2k
4d3reg
8d3reic
dre2if
d5rei1fe
8drem
8d1ren
2d1rer
8dres.
6d5r1h8
1dria
d1ric
8dri2n1d
droi6
dro5x
1dru
8drut
drö2s5c
1drü
drü5b
drü8sc
2ds
d1sa
d6san
d1sat6
d1sc
dsc8h
5d6scha.
d1schi
5dschi1k
d1se
dse8e
d8se8r1g
8ds1l
d1sp2
d4s1pak
ds2p2o
d8spä
d1st
d1sü
2dt
d1ta
d1te
d1ti
d1to
d2t1s6
d1tu
d5tä
1du
du5a2ls
du1b6
du1e
du2ft
duf4t3r6
4d3uh
d6ui
du5ie
8du2m1l
8du2m1w
2d1u2n1d
du8ni
6d5unt
dur2c
durc8h3
6dur1l
du2r1s
6dursa
8du2r1t
dus1t
dusc8h
du8sc6hr
2d1v
2d1w
dwa8l
2d1z
1dä
6däh
8dä2n1d
dä6r
dö1b
dö8bl8
d5öl
dör1f
dör6fl
dö8sc
d5ö4st
1dü
ea1be
ea4ben
e1ac
e1ah
e1a2k1t
e1al.
e5al1f
e1a2l1g
ea1li
e5a8lin
e1a6l1k
e1a6ll
e5a6l1p
e1a2l1t
e5a2l1w
e1am
e1a2n1d
ea1ni
ea6nim
e1ar.
e5ar1f
e1a6rk
e5a6r1m
e3a2r1t
e5at.
e6a1te
e6a5t6l
e8a2ts
e5a2t1t
e6au.
e1aus
e1b
e1ba
e6b5am
e1be
ebe6ns
eben4s5e6
ebl8
eb1li
eb4lie
e8bs
eb1se
eb4ser
eb1si
eb4s3in
ec8h
e1che
e8cherz
e1chi
e6ch3m
8e2ch3n6
ec6h1r
e2chs
ech1se
ech8se2n1d
ech4su
e1chu
ec2k
ec1ka
eck5an
e5c2l
e1d
ee5a
ee3e
ee5g
e1ei
ee5isc
eei4s3t
ee1le
ee6le2n1d
e1e6ll
ee5lö
e1e8rd
ee3r4e
ee8reng
eere6s5
ee5rä
ee1ta
ee6tat
e1ex
e1f
e6fau
e1fe
e8fe8b
e2ff
ef5fe
3effek
efr6
ef3rom
e1ge
ege6ra
eg1los
eglo6si
1egy
e1ha
e6h5ac8h
eh5a6ns
e6hap
eh5auf
e1he
e1hi
ehl3a
eh1le
eh3l5ein
eh1mu
eh1ne
eh2n5ec
e1ho
e6hr
ehr1a
eh1re
ehre6n
eh1ri
eh1ru
eh6r5um
e1hu
eh1w
e1hy
e1hä
e1hö
e3hüt
ei1a
eia6s
ei1ba
ei6bar
eic8h
eich3a
eic6h5r
ei1d
ei4dar
ei1de
ei6d5ei
ei8der1f
ei2ds
ei3d4sc
ei1e
e2if
ei1fe
8eifen
eifr6
3eifri
1eign8
e2il
ei6l1d
ei1ma
ei6mab
ei8mag
ein1a4
ei8nat
ei1ne
ei8ner1h8
ei8ness
ei6ne1te
ein1g
e8i1ni
ein1k
ei1no
ei6n5o1d
ei8no1k
ei4nor
ei6ns
e3in1sä
e2i1o
e1i2rr
ei5ru
ei1sa
ei8sab
eisc8h
ei5s2chn6
ei1se
ei6s5ent
ei1so
ei8sol
ei1ta
ei4t3al
eit3ar
eit1h
ei6thi
ei8tho
ei2ts
eit1sam
eit8sa2m1t
ei1tu
ei6t5um
e1j
1e4k1d
e1ke
e1ki
e1k2l8
e1kn8
ek2ni4
e1la
e2l1al
6elan
e6lan1f
e8l1an5l6
e6l5a6ns
el3ar1b
el3a6r1m
e6l3a2r1t
5e6las1ti
e6lau1ge
e2lb
el8bs
elb1st5a
e1le
6ele1f
ele6h
e6l5e1he
e8le2if
e6l5ein1h
1elek
e8lel
3ele1me
e6lemen
e6len1te
e6l5e1pi
e1ler
e4l3e2rr
ele2r1s
e6l5ersc
el1f
elf2l
e2l1g2
e1li
e6l5i6ns
e6ll
el1le
el1l8er
4e1lo
e4l3o1fe
e2ls
el1so
el8soh
e2l1t
el5ten
el8tent
5elte2rn
e1lu
elut2
e1lä
e1lü
e2m1d
em1de
em8dei
e2m1m
em1me
em8meis
4e1mo
emo5s
e2mp
1emp1f
1emp1t
e2m1t
1emto
e1mu
emu6rk4
emur2ks5
e1mä
ena1be
en5a6ben
ena2c
enac8h
en5a2chs
en5ac2k
e1na1d
en5af
en5a6ll
en3a2l1t
en1am
en3an.
en3ant
en3anz
en1a6p
en1ar
en1a6s
6e1nat
e4n3auf
en3aus
en1c
en2ce
e2n1d
enda6l
en1de
end5er1f
end5e8r1g
en8dess
e1ne
4ene.
e2nec
en5ec2k
ene1f
e8ne2ff
e6n5e6hr
e6n5eim
e8n3eis
6enem.
6enen
e4nent
4ener.
e8ne8rd
e6n3er1f
e4ne8r1g
5ener1gi
ener1l
e6n5erla
en5e2r1s
e6nerst
en5er1w
6enes
e6n5ess
e2nex
en3glo
2e1ni
en1ni
enn6i6s5
en1no
enn6os4
en6ns8
e1no
eno1be
e6nober
eno8f
e6n5opf
e4n3o8rd
e6ns
en1se
en8se2r1s
ens1k2
ens8kl8
en1sp2
ens1p2o
ens6por
en1ta
en5t6ag
en4t3a5go
en1te
enter1b
en8ter1bu
en1ti
en6ti1d
en2t1l
3entl8a
en1tr6
ent5ric
en2t1w
5entwic
5entwu
1en2t1z
e1nu
en6u5i
e3ny
en1za
en8zan
en1öf
e1nös
e1nüg
eo1c
e5o6fe
eo1k
e5o2k1k2
e1on.
e3on1f
e5on1k
e5on5l6
e5on1r
e5opf
e5ops
e5or.
e1o8rd
e1o8r1g
eo5r6h8
eo1t
e1pa
e1pe
e8pee
e6p5e6g
ep5ent
e1p2f
e1pi
5epi1d
epi1de
e6pidem
e1pl8
e1p2o
5epos
e6pos.
ep4p3a
e1pr6
e1pä
e1q
e1ra.
er5aal
8er6a1ba
era1be
e5r6ab8el
er5a6ben
e5ra1bi
er3a8b1s
er3ac8h
era5e
era5k6l8
e2r3a6ll
er3a2m1t
e3r6a2n1d
e3ra1ne
er3a6ns
e5r8anz.
e1rap
er3ar1c
e3r2a1ri
er3a6si
e1rat
era2t3s
er3auf
e3r6aum
er1b
er8bs
3erb1se
er1c
e1re
4e5re.
er3ec2k
er5e2g1g
e2r5e2h
2erei
e3r4ei.
e8rei1ne
e6r5ein1r
6eren.
e4r3en1m
e1rer
4erer.
e6r5e6r1m
er5er5o
ere2r1s
er5erst
e4r3erz
e2r3ess
er1f
er1fü
5erfül
e8r1g
er1ga
er8gan.
er1ge
erge1b
5erge2b1n
er2g5h
er1gä
5ergänz
er1h8
5erhö1hu
2e1ri
eri5ak
e6r5iat
e4r3i2n1d
e6r5i6n5i6
er5i6ns
e6r5int
er2it
eri1ti
er5it2io
e6rk
er1kl8
3er1klä
er1l
er1lös
5erlös.
e6r1m
er1me
erme6n6s
e2rn
er1na
er6nab
er6ns
3ernst
6e1ro.
e1ro1d
er1o2f
e1r8o1g
6e3roi
ero5i1d
ero8i1de
e3rol
e1rom
e1r2on
e3rop8
e2r1or
e1ros
e1rot
er5ox
e2r1s
ersc8h4
er1sta
5erstat
e2r1t
er5tei
er6t5ein
er2t1h
er5t6her
2e1ru
e1r4uf
eru2f4s3
e4r3u6hr
e2r3u2ms
e5r6us
er1w
5erwer1b
e1ry
erzw8
er5zwa
er3zwu
erä8m
er5äs
erö8
e3rös.
e6r1ü2b
e1sa
esa8b
e8s1ap
e6s5a6v
e1sc
esc8h
esch4l6
e1se
ese1a
ese1b
es5e1be
eser1v
eser1ve5
e8s1h
e1si
es2il
es5i6ll
es3int
es1k2
es1k2o
es4kop
e2s1l
e1so
eso8b
e1sp2
es1pe
es4pei6s5
es2p2o
es2pu
e2s1se
5essenz
e1sta
e6s4ta8b1s
e6staf
e6st5ak
est3ar
e1sto
e8stob
e1str6
e6st5res
e1su
es3ur
e2s1z
e1sü
e1ta
e1t8ag
e1t2a1ri
etar2i5e
et8a8ta
e1te
eten6te
eth6a
et5hal
e5thel
e1ti
1e2t1n
e1to
e1tr6
e2t3rec
e2ts
etsc8h
e8tscha
et8se
e2t1t
et6tei
et2th
et2t1r6
e1tu
etu1s
e2tz
et1ze
et8zent
et8zw8
e1tä
e1tö
e1tü
eu1a2
eu1e
eu1er
eue1re
eu2e8rei
eu5fe
e6ui
euin5
e6uk2
e1um.
eu1ni
eu6n2io
eun1te
e5unter
eu1o6
eu5p
eu1ro
3europ
eu1sp2
eu5str6
eu8zo
e1v
eva2l6s
e1ve
ever1
eve2re2
eve5r6en
ev2e1r4i
e1w
e2wig
e1xo
ex1or
1e8x3p2
e8x1t
1extr6
ey3er.
e1z
e1ä2
e5ö8
e1ü
e1ße
e8ßes
fac8h
fa6ch5i
fa1d
fa1de8
fa6del
fa5el.
fa6ll
fal6lo
fa2l1t
falt8e
fa1na
fan4gr4
6f1an5l6
6fap
far1b
far6ba
far4bl8
fa2rr
far6r5a
2f1a2r1t
fa1sc
fau8str6
fa3y
2f1b2
6f1c
2f1d
1fe
2f1ec2k
fe1d
fe6dr4
feh1le
feh6lei
f6eim
8fei6ns
f5eis
fe1le
fel5en
fe2l1t
8f5elte2rn
8fe2mp
fe5rant
fe8rd
4ferd.
fe2rr
fer1ri8
fe1sto
fe8stof
fe6str6
fe1stu
fe6stum
fe1ta
fe8t8ag
fe2t1t
fet6ta
fex1
2ff
f1fa
f6f5a6r1m
f5fe
ffe5in
ffe6la
ffe1le
ffe8ler
2f2f1f
f1fla
ffl8e
ff3lei
ff1li
ff4lie
f2fs
ff8sa
ff6s5ta
2f1g2
f1ge
fge1w
fgewen6
4f1h
1fi
fi1d4
fi3ds
fie1b4
f2il
fi1la
fi1le
fi8lei
fi2l1m
fil4m5a
f8in.
fi1na
8fin1f
fisc8h
fi8scho
fi6u
6f1j
2f1k2
f8lanz
fl8e
4f3lein
f1li
8flib
4fling
f2lix
6f3l2on
5flop
1flor
5f8läc
3flöt
2f1m
2f1n
1fo
foh1
f2on
fo6na
2f1op
fo5ra
fo6r1m
for1me
for8mei
fo2r1s
for8str6
fo2r1t
for8th
for6t5r6
fo5ru
fo2t1t
6f5otte
2f1p8
f1q
fr6
f5ram
1f8ran
f8r8aß
f8re.
frei1
5fr4ei.
f3reic
f3rest
f1rib
8f1ric
6f1r2ig
1fr2is
fr2on
fro8na
fräs5t
2fs
f1sc
f1se
f2s1er
f5str6
f1stä
fs3tät
2ft
f1tak
f1te
ft5e6h
fte1re6
ft1h
f1ti
f5to
f1tr6
ft5ra1d
f2ts
ft1sc
ft2so
f1tu
f2t1w
ft1wi3d4
f2t1z
1fu
6f5u2ms
6fun1f
fun4ka
fu1ße
fuße6n
fu8ße2n1d
6f1v
2f1w
2f1z
1fä
fä1c
8fä6r1m
6f1äug
fä8ß
fö1de3
8föf
3för
1fü
fün1f
fün4f3u
1ga
ga6bl8
6g1a2b1w
8ga8b1z
ga1d
ga1de
g3a4der
ga8ho
ga5isc
4gak
ga1la
6g5a2m1t
ga1na
ga1ne
gan5er1b
1gan6g5a
ga5n1j
6g1an5l6
ga6ns
8gan1sc
6gar1b
2g1ar1c
2g1a6r1m
ga5ro
ga2r1t
6g3arti
ga8sa
ga8sc
ga1str6
ga6st3re
2g1a2t1m8
6g5auf
gau5fr6
g5aus
2g1b
g5c
6gd
g1da
1ge
ge1a2
ge6an
ge8at.
ge1e2
ge6es
ge1f2
8ge2ff
ge1g2l
ge1im
4g3ei1se
geist5r6
ge2lb
gel1br
gel8bra
ge2l1t
gel2t8s
ge5lö
g2e1ni
ge8nin
gen3k
6g5en2t1f2
ge3nä
ge1or
ge1ra
ge6rab
ger8au
ger1h8
8gerhö
g2e1ri
ger8i6ns
ge1ro
6g5erz.
ge1rä
ge1rü
ge1s
ge1s2p2
ges1te
ge2s7te.
ge2s7ten
ge2s7ter
ges1ti
ge2s7ti1k
ge5unt
4g3ex3
2g1f8
2g1g
g1ha
6g1hei
5ghel.
g5henn
6g1hi
g1ho
1g6hr
g1hö
1gi
g2il
gi5la
gi1me
gi8me.
gi1na
4g3i6ns
gis1tr6
g1j
2g1k
8gl.
1gla1d
g5lag
glan4z3
1glas
6glass
5glaub
g3lauf
1gle.
g5le1b
3gleic
g3lein
5gleis
1glem
2g1ler
8g3leu
g1li
gli8a
g2lie
3glie1d
1g2li1k
1g2lim
g6l2io
1gloa
5glom
1gl2on
1glop
g1los
g4loss
g5luf
1g2ly
1glü
2g1m
gn8
6gn.
1gna
gna2c
8gnac8h
2g1n2ah
g1nas
g1ne
g8neu
g1ni
g2n6ie
g3n6is
1gno
8gnot
1go
goe1
8gof
2g8o1g
5go1gr4
6g5oh
g8o1ni
gon6i5e
gon6is
6gonist
go1ra
8go8rd
2g1p2
g1q
1gr4
g5rahm
gra8m
gra4s3t
6g1rec
gre6ge
4g3reic
g5reit
8grenn
gr2i4e
g5riem
5gr2if
2g1r2ig
g5ring
6groh
2grot
gro6ß
4grut
2gs
gs1ab
g5sah
gs1ak
gs1an
g1s8a2n1d
gs1ar
gs1au
g1sc
g1se
gs1e1f
g5s8e2il
gs5ein
g2s1er
g1si
gs1in
g2s1o
gso2r
gsp2
gs1pr6
g2s1u
2g1t
g3te
g2t1h
1gu
gu5as
gu2e
2gue.
6gue1d
4g3uh
8gu2ms
6g5unt
gut3h
gu2tu
4g1v
2g1w
gy1n
g1z
1gä
8gä8m
6gä6r1m
1gö
1gü
6güb
1haa
ha1b8r
ha1d
ha1de
ha8del
hade4n
8hae
ha5el.
ha2ft
haf6tr6
2hal.
ha1la
ha2lb
hal4b5a
6ha1le
8han.
ha1na
ha2n1d
han6dr4
han1ge
han6ge.
2ha1ni
h5an1th
6hanz
6har1b
h3ar1be
ha6r1m
h3ar1me
ha5ro
ha2t1h
h1a2t1m8
hau1sa
hau6san
h8a8ß
h1b2
h1c
h1d
he1b
he2bl8
hec8h
he3cho
h3e2cht
he1d
he5d6s
he1f
5he2ft
he1he
h5e6he.
hei1d
hei8ds
h1e2if
2hein
he3i2s1m
he5i2st.
hei2t8s3
he2k1t
hek6ta
he6ll
hel1la
hel8lau
8he2l1t
he1me
he6mer
1he2m1m
6h1e2mp
he1ne
h6enen
hen5e2n1d
henkl8
hen5klo
hen1tr6
hen6tri
he2nu
8heo
he8q
her3ab
he5rak
her3an
4he1rap
her3au
her1b
h3er1bi
he1ro
he8ro8b
h2e1ru
he4r3um
her1ze
her6z5er
he1sp2
he4s1pe
he1st
he1ta6
het5am
he5th
heu3sc
he1xa
hey5e
h1f2
h1g
h1go
hgol8
h1h
h1iat
hi2e6r5i
hi1k
hi5k1t
h2il
hil1a2
hil1f
hil4fr6
hi5nak
hin4ta
hi2nu
h2io
hi5ob
hi2rn
hir5n5e
hir6ner
hi1sp2
hi1th
hi5tr6
5hi2tz
h1j
h6jo
h1k2
hla2b1b4
hla4ga
hla6gr4
h5lai
hl8am
h1las
h1l8aß
h8l1c
h1le1d
h3lein
h1ler
h5l6er.
h1li
h2l2if
h2lim
h8lin1f
h2l5int
h2l2ip
h2lit
h4lor
h3l6o1se
h1läs
h1me
hme5e
h1ne
h2nee
h2nei
hn3eig
h2nel
hne8n
hne4p3f
h2n8erz
h6ne2tz
h1ni
h2n2ip
h2nit
h1nol
h6ns
hn5sp2
h1nu
h2n2uc
h2nu1d
h2nul
hoc8h1
1hoh
hoh1le
hoh8lei
2hoi
ho1la
ho4l3ar
1holz
h2on
ho1ra
6ho8r1g
ho2rn
5horn.
ho3s1l
hos1p2
ho4spi
h1p
hpi6
h1q
6hr
h1rai
h8rank
h5r6aum
hr1c
hr1c6r
hrcre8
h1re1d
h3reg
h8r4ei.
h1rer
h4r3er1b
h8re2r1t
h8r1g2
h1ric
hr5i6ns
h2rom
h2r1t
hr6t5er1l
hr2t1h
hrtr6
hr6t5ra
hr8tri
h6rum
hr1z
hs3ac8h
h1sam
h6s5a2m1t
h1sc
h1se
h6s5ec
h6s5er1l
hs8erle
h1so
h4sob
h1sp2
h8sp8aß
hs1pe
h8spel
hs6p2o
hs1pu
h4spun
h1str6
h1stu
h4s3tum
h1su
hs3u2n1d
h1sü
h5ta.
h5tab
ht3ac
ht1ak
ht3ang
h5tanz
ht1ar
ht1at
h5taub
h1te
h2t1ec
hte1f
h4t3e2ff
h2t3e1he
h4t3e2if
h8teim
h4t3ein
h4t3eis
h6te2mp
h8ten2t1f2
hte1re
hte8ren
hter1f4
h6ter1fü
hte8r1g
h8ter1gr4
h4t3er1h8
hte2r1s
h6t5ersc
h8terst
h8te1se
h8tess
h2t1eu
h4t3ex
ht1he
ht5hu
h1ti
htr6
ht5rak
h2ts
hts3ah
ht1sc
ht1se
ht6sex
ht8s1k2
ht8so
h1tu
h2tz8
h5tüm
hub5l8
hu6b5r
huh1l
hu6hr
h5uhr.
hu6ld
huld5a6
hu1le
hu8lent
hu8lä
h5up.
h1v
h5weib
h3weis
h1z
hä1k
hä8kl8
hä2l8s
hä1ma
häm6a8tu8
häsc8h
hä1sche
hä8sche.
hä2t1s
häu4s3c
2hö.
2höe
8höi
hö6s
hös5c
hüh1ne6
hü2ls
hül4s3t
hü2t1t
hütte8re
ia1d
i5a2d1n6
i1af
i5ak.
i1al.
i1al1a
i1a2lb
i1a6ld
ia1le
i5alei
i1al1f
i1a2l1g
i3a6l1h
i1a6l1k
i1a6ll
i1a6l1p
i1a8l1r
i1a2ls
i1a2l1t
i1al1v
i5a2l1w
i3alz
i1an.
ia5na
i3a2n1d
ia1n8e
ia8ne8b
i1ang
i3ank
i5ann
i1ant
i1anz
i6a1p2o
i1ar.
ia1ra
ia6rab
i5a2rr
i1as.
i1a2s1m
i1ass
i5a2st.
i1at.
i5a2ts
i1au
ia1z
i5a2z1z
i1be
i6b5eig
i6b5ei1s
ibl8
ib2le
ib1li
i4blis
i1br
i6b1r2ig
i1bu
i6b5unt
i1bü
i6büb
ic8h
i1che
i6ch5ei
i6cher1b
i1chi
i6ch5i6ns
ich1l6
i6ch3m
i2ch1n6
i1cho
i2cht
icht5an
icht3r6
i1chu
i8ch1w
ic2k
i2c2ks
ickst8
ick6s5te
ic5l
i1d
id3a6r1m
i1de
3i2deal
ide8na
3i2deol
ide5rö8
i1di
id2io
i6diot
idr4
id5rec
i2d1t
ie1a
ie1b
ie1ba
ie6b5ar
ie1be
iebe4s3
ie2bl8
ie1b1r
ie8bra
ie4bre
ie8bä
ie1d
ie2dr4
ie1e8
ie1f
ie6f5a1d
ie2f5f
ie2f1l
iefr6
ie4fro
ie2f1t
i1ei
ie1le
ie4l3ec
ie8lei
i1e4lek
i3e6ll
i1en.
i1e2n1d
ie1n6e
i3en1f
i5enn
ien1ne
ien6ne.
i1en1p2
i1en1r
ie6ns
i5ensa
ien1sta
ien8stal
i5en1v
i1enz
ie5o
ier3a4b
ie4rap
i2e1re
ie4rec
i2erei
ie6r5ein
ie6r5eis
ie1r8er
ie2rn
i3ern.
i2e1ru
ie8rum
ie8ru2n1d
ie1sc
iesc8h
ie6s5che
ie1ta
ie6tau
ie1te
ie8te2r1t
ie5the
ie1tr6
ie6t5ri
i1e2t1t
ie5un
iex5
2if
i1fa
if5ang
i6fau
i2ff
if1fr6
if5lac
if1li
i5f6lie
ifr6
i1fre
i2ft
ift5a
if6t5r6
i1ga
ig3a2r1t
2i1ge
ige1s
i8gess
ig5he
i5gla
ign8
ig2ni
i5go
i1gr4
i2g3rot
i2gs
ig3s2p2
i1ha
i8ham
i8ha6ns
i1he
i1hi
ih1n
i6h1r
i1hu
i8hum
ih1w
8i1i
ii2s
ii2t
i1j
i1k
i1ka
i6kak
i8kerz
i6kes
ikl8
ik4ler
i1ku
i6k5unt
2il
i5lac
i1lag
il3a6ns
i5las
i1lau
il6auf
i1le
ile8h
i8lel
il1f
il2fl
i1li
il2ip
i4l3ipp
i6ll
il1le
il6l5enn
i1lo
i2l1t
ilt8e
i1lu
i1lä
i1ma
i8ma2r1t
i2m1b2
i1me
i8me1le
i1mi
i8mi1d
i2m1m
im1me
imme6l5a
i1mu
i1mä
i5mö
i1n2ah
ina5he
i1nat
in1au
inau8s
i2n1d
8ind.
in4d3an
in1de
5index
ind2r4
in1du
3indus
i1ne
i5nec
i2n1ei
i8ner1w
in1f
in1fe
3infek
1in1fo
in1ge
ing8en
5ing2e1ni
in2gs
ing5s6o
in1h
5inhab
i1ni
in6ie
ini5er.
5in1j
in1kä
in8kät
in1na
in8nan
i1no
inoi8d
ino1k
in3o4ku
i6ns
in5sau
in1sp2
5in1s2pe
ins1ti
5instit
in1str6
5instru
ins1z
ins4ze
in1te
5inte1re
5inter1v
in3the
in5t2r6
i5ny
inä2
i1när
in1äs
inö8
in5öd
i1nös
2io
io1a8
io1c
io1d
io1de4
io2di
ioi8
i1ol.
i1om.
i1on.
i5on1b2
i1o6n2s1
i1ont
i5ops
i5o8p1t
i1or.
i3oral
io3rat
i5orc
i1os.
i1ot.
i1o8x
2ip
i1pa
i1pi
i1p2l8
i1pr6
i1q
i1ra
ir1b
ir6bl8
i1re
i1ri
i6r1m
ir1me
ir8me8d
ir2m1o2
i2rn
ir1na
ir8nak
i1ro
i2rr
irr1h8
ir5rho
i2r1s
irsc8h
ir6schl6
ir6sc6h5r
i5r6us
i5ry
i5rä
i1sa
i1sam
i8sa2m1t
i6sar
i2s1au
isc8h
i1sche
i8scheh
i8s6chei
is6ch5m
isc6h3r
ischä8
i1se
is8e1le
ise3ra
i4s3er1h8
is3e2rr
i1si
isi1d
isi6de
i8si2n1d
is1k2
is1k2o
is4kop
i1so
is2on
iso1n5e
isp2
is1p2o
is6por
i1stu
i8s5tum
i5s1ty1
i5sö
i1ta
i4t5ab.
i2t1a2m
i8ta1x
i1te
ite2r1s
i8tersc
i1thi
i1tho
i5t6hr6
i4t8hä
i1ti
i8ti8d
iti1k
iti6kl8
i2t1m8
it1me
itmen4
i1to
i8tof
itr6
it3ran
it3rau
i1tri
itr2i5o
i2ts
it1sc
it2se
itsp2
it5spa
i2t1t
ittr6
it8tru
i1tu
i2tz
it1ze
it6z5e8r1g
it6z1w8
i1tä
itä6r5e8
ität2
itä2ts5
i1tü
i1u
iu6r
2i1v
i6va1d
iv2a1ti
iva8tin
i1ve
i8vei
i6v5e1ne
iver1
i8ver1h8
i2vob
i8vur
i1w
iwi2
i5xa
i1xe
i1z
i1ze
ize8n
i1zi
i8zir
i6z5w8
iä8m
i1ä6r
i5ät.
i5äv
i1ö8
iü8
i1ße
i6ß5e2r1s
ja5la
je2t3r6
6jm
5jo
jo5as
jo1ra
jou6l
j2uc
juc8h
ju5cha
ju1ge
jugen4
juge2n1d5
jun2g5s6
3jä
1ka
kac8h
8ka2chs
8ka2k1z
ka1la
ka6l5d
ka2m5t
ka1na
2k1an5l6
8kapf
k8a6pl8
ka5r6a
kar1b
6k3ar1be
ka1ro
kar1p
kar6p5f
ka2r1t
4k3arti
8karz
ka1rä
ka1si
kasi5e
ka1te
ka6te1b
ka2t1t
kat8ta
kau2f6s
kau3t2
2k1b
2k1c
4k1d
ke6hr
keh2r6s
kehrs5a
8keic
2k1eig
6k5ein
6k5eis
ke1la
ke6lar
ke1le
ke8leis
k4e8lo
8ke2mp
ken1te
k5ente.
k3en2t1f2
8k5en2t1s
6k1en2t1z
ke1ra
ker1l
k5erlau
2k1f8
2k1g
2k1h
k2if
ki5fl
8ki1k
kin2g6s5
6kin1h
k2io
ki5os
ki5sp2
ki5th
8ki8ö8
2k1k2
kl8
1kla
8klac
kla1ge
k5lag8er
kle1b
kle4br
k3leib
3klei1d
kle5isc
4k3leit
k3lek
k1ler
6k5l6er.
5klet
k1li
2klic
8k3lig
k2lim
k2lin
5kl2ip
5klop
k3lor
1klä
2k1m
k1ma
k3man
kma1ni
kman6i5e
kn8
k1ne
6kner
k2ni
knä8
1k2o
ko1a2
ko1d
ko1de
ko6de.
ko1i
koi8t
ko1mi
ko6min
ko1op
ko1or
ko1ph
ko6pht2
ko3ra
ko8rd
kor1de
kor6d5er
ko5ru
ko2ts
ko5t6sc
k3ou
3kow
6k5ox
2k1p2
k1q
1kr8
4k3ra1d
2k1rec
4k3reic
kre5i1e
2krib
6k1r2ig
2kr2ip
6kro1ba
2ks
k1sa
k6sab
k1sal
ksa2l8s
k1sam
k8sa2m1t
k6san
k1sc
k1se
k2s1ex
ksp2
k5spat
k5s1pe
k1spi
k8sp2il
ks1p2o
ks6por
k1spr6
kst8
k1su
k2s1uf
2k1t
kta8l
kt5a6re
k8tein
kte8re
k2t1h
k8tin1f
ktr6
k2t3rec
k2t1s
1ku
k2uc
ku1c8h
kuc2k8
k3u6hr
k6ui
ku5ie
ku2m2s1
kun1f
kun2ft
kunf2ts5
ku6n2s
kunst3
ku1ra
ku8rau
ku4ro
kurz1
4kus1ti
ku1ta
ku8ß
6k1v
2k1w
ky5n
2k1z
1kä
kä4m
4k3ä1mi
kä1se5
1kö
kö1c
kö1s
1kü
kü1c
kü2r1s
kür6sc
1la.
8l1a2b1f8
8la2b1h
la1b2r
2l1a8b1s
lac8h
lac6h3r
la1d
la8dr4
5la1du
8l1a2d1v
6la2ff
la2f5t
la2gn8
la1ke
5laken
8la2m1b
la1me
la6mer
la2mp
lam1pe
5lampe.
2l1a2m1t
la1na
1la2n1d
lan4d3a
lan4d3r4
lan4gr4
lan1m
8lan1me
6lann
8la8n1w
6lan1ä
8l1ap1pa
lap8p1l8
lap6pr6
l8ar.
la5ra
la4r4af
la8rag
la8ran
la6r5a6s
lar1b
l3ar1be
l2a1re
la8rei
la6r1m
6larm.
la8sa
la1sc
la8sta
l2a1t8i
6l5a2t1m8
4laus3s4
4l1au1to
1la1w
2lb
l1ba
l8bab
l8bauf
l1be
lbe1d
l8be1de
l1bi
l4b3i6ns
lbl8
l5blo
l8bs
lb1sta
lbst5an
lbs1t3e
8lc
lc8h
l1che
l8che2r1t
l1chi
l6ch3m
l5cho
l8ch5w
6ld
l1de
l4d3ei
ldr4
ld1re
l1dü
l6düb
le1b
le2bl8
le1br
le8bre
lec8h
le2cht
lech2t6s5
le1d
led2r4
le1f
6le2ff
le1ga
le4gas
1le6hr
lei6br
le8in1f
8leinn
5lei1stu
le2k1t
4lektr6
le1le
le1ler
le6l5e2r1s
l4e1mo2
8le2mp
l8en.
le2n1d
8len2ds
len1du
6lendun
le1ne
l6enen
le8ne2n1d
len8er1w
6l5en2t1s
4l3en2t1w
4l1en2t1z
8len1zy
8leo1z
6le1pi
le6p2ip
8le1p2o
1ler
l6er.
ler1b
8ler8bs
le8rd
6l5er1de
le1re
l2erei
le8reis
le8re2n1d
le4r3er
4l3e8r1g
l8er1gr4
le6rk
6ler1kl8
ler1zi
6l5erzie
8lerö8
le1se
8lesel
le1si
lesi5e
les1k2
le3s1k2o
le3th6a
le2t1s
5le2uc
4leu1ro
leu4s3t
le5xe
6l1e8x3p2
l1f
2l1g
l1ge
lge2n1d8
l8gh
lg1li
lg2lie3
l3glie1d6
6l1h
1li
li1ar
li1as
2lic2k
li1d
li8dr4
li1en
li5en6n
li8e2r1s
li8e2r1t
2ließ
3lig
li1ga
li8ga8b
li1g6n8
l2il
li1l8a
8li2m1b2
li1na
li2n1d
4l3in1du
lin2gs5
4l3in1h
6l5in1j
lin2k4s3
4lin2k1t
2lint
8lin1v
l2ip
4lipp
5lip1t
li1sa
4li1sam
l2i1v
livi5e
6l1j
6l1k
l8keim
l8kj
lk2l8
l1k2o
lko8f
lkor8
l2ks
lk2sa
lk2se
6ll
l1la
ll3a4be
l8la2b1t
ll8an5l6
l2l1b
l8l1c
l6l1d6
l1le
l4l3eim
l6l5ei1se
l1ler
ller3a
l4le1ti
l1li
l5l2ip
l1lo
l4l3o2r1t
ll5o1v
l2ls
ll1sp2
ll6spr6
l2l1t
llte8
l1lu
l4l3u8r1g
l1lä
l5lü
l6lüb
2l1m
l1mo
l6m5o6d
6ln
l1na
l1no
8lo1bl8
lo6br
loc8h
3lo2ch.
lo1fe
l5o4fen
l8o1g
lo1ge
5loge.
5lohn
4l3o6hr
1lo1k
l2on
lo1pe
4l3o4p8er
lo1ra
2l1o8rd
6lo8r1g
4lo2r1t
lo1ru
1los.
l6o1se
lo8sei
lo1si
3losig
lo1v
lo6ve
lo1wi5
6l1p
lp2f
l1ph
l8pho
l8p1n
l2pst
lp4s3te
l2p1t
l1q
8l1r
2ls
l1sa
l6s1a6r1m
l1sc
l1se
l8sec
l6s5e8r1g
l4s3e2r1s
l8s1h
ls1l
l5s6la
l1sp2
ls1p2o
ls4por
ls2pu
l1str6
l1su
l8su1ni
l1sü
2l1t
l6t5a2mp
l4t3ein
l5ten
l6t5eng
l6t5er1p
l4t3hei
lt3her
l2t1ho
l6t5i6b
lt2i1l
ltr6
l8trö
l2ts
lt1sc
lt1se
lt6s1er
lt4s3o
l1t5u2ms
lu8br
lu1d
lu2dr4
lu1en8
8lu8fe
lu2ft
luft3a
luf8tr6
lu6g5r4
2luh
l1u6hr
l6ui
lu5it
5l6uk
2l1u2m1f6
2l1u2m1w
1lun
lu1ni
6l5u6n2io
4l3un1te
lu5ol
4lu8r1g
6lu2r1s
l3u2r1t
lu4sto
lus1tr6
lu6st5re
lu8su
lu6tal
lu1te
lu6t5e6g
lu8te8r1g
lu3the
lu1to
lu6t5or
lu2t1r6
lu6ß5
l1v
l1ve
lver1
lv2e5r6u8
2l1w
1ly
lya6
6ly2m1p2
ly1no
l1ze
l8zess
l1zo
l8zo8f
lzw8
l3zwei
lz5wu
3lä2n1d
lä5on
lä6sc
lä2t1s
5läuf
2l1äug
läu6s5c
lä5v
l1öl
1lös
lö1ß6t
6l1ü1b6e2
1ma
8m1a2b1g2
mac8h
ma5chan
ma1d2
ma5el
4ma2g1g
ma1g8n8
ma1la
ma8lau
ma6l5d
8mal1de
ma1li
mali5e
m8a1lu8
ma8lut
2m1a2mp
3man
ma2n1d2
man3ds
8man1gr4
ma1ni
man2i5o
ma6ns
8m5an1st
6m1ap1pa
mar1b
4m3ar1be
ma6rk
mar8kr8
ma1r4o
ma2r1s
marsc8h
mar8s6ch2m
3mas
ma1sc
ma1tö
4m5auf
ma5yo
2m1b
m1b6r
2m1c
2m1d
m2ds
md6sä
1me
me1c8h
me5isc
5me6ld
me2ls
mel8sa
8me2mp
me5nal
me2n1d
men4dr4
me6ns
men1sc
mensc8h
men8schl6
men8s8chw
men2t1s
8mentsp2
me1ra
me8r1g
mer4gl
me1ro
3mes
me1se
me6s5ei
me1th
me8ß
2m1f6
2m1g
2m1h
1mi
mi1a
mi6a1le
m2il
mi1la
2m1i2m1m
mi1na
mi5nü
mi1sa
mi4s3an
mit1h
mitr6
mi5t6ra
3mi2t1t
mitta8
mi6ß5
6mj
2m1k8
2m1l
2m1m
m1ma
m6ma1d2
m6m5ak
m1me
m8menth
m8men2t1w
mme6ra
m2m1n8
m2ms
mm5sp2
mm5u2ms
mmu2t5s
m8män
m1n8
m5ni
1mo
mo5ar
mo1d
mo4dr4
8mof
m8o1g
mo1ga
mo8gal
mo1k
mok2l8
mo4kla
mo6l5d
m2on
mo2n1d
mon8do
mo1no
mo4n3o1d
m1o6ns
mon2s1tr6
mon1t8a
6m5ony
mo1pa6
mo1ra
mo8rd
mor8d5a
mo1sc
mo1sp2
5mot
moy5
2mp
m1pa
mpfa6
mpf3l
m1ph
mphe6
m1pi
mpin6
m1pl8
mp2li
m2plu
m1p2o
mpo8s1te
m1pr6
mprä5
mp1t
mp8th
m1pu
mput6
mpu5ts
m1pö
8m1q
2m1r
2ms
ms5au
m1sc
msc8h
msch4l6
msp2
ms6p2o
mspr6
m3spri
m1str6
2m1t
mt1ar
m8tein
m2t1h
m2ts
mt6se
mt8sä
mu5e
6m5uh
mu1mi1
1mun
mu2n1d
mun6dr4
mu1se
muse5e
mu1ta
2m1v
mvol2
mvo6ll3
2m1w
1my
2m1z
mä1k
mä6kl8
1män
mä1s
mä5tr6
mäu4s3c
3mäß
mö1b2
6möl
1mü
5mün
3müt
1na.
n5ab.
8n1a2b1n
n1a8b1s
n1a8b1z
na6bä
na2c
nac8h
na1ch3e
3na2cht
1nae
na5el
n1afr6
1nag
1n2ah
na8ha
na8ho
1nai
6nair
na1k2o
na4kol
n1a2k1t
nal1a
8na1ly
1na1ma
na1me
na4mer
na1m2n8
n1a2mp
8n1a2m1t
5nan1c
nan6ce
n1a2n1d
n6and.
2n1ang
1na1ni
1nann
n1a6ns
8na8n1w
5napf.
1n2ar.
na2ra
2n1ar1c
n8a8rd
1n2a1ri
n8a6rk
6n1a6r1m
5n6a2r1s
2n1a2r1t
n8ar1v
6na2t1m8
na2ts
nat6s5e
1nau1e
4nauf
n3aug
5na6ui
n5a6uk
n6a5um
6n1au2s1b2
6n1au1to
1na1v
2na1x
3na1z
1n8aß
n1b2
n1ba
nbau5s
n1c
nc8h
nche5e
n6ch5m
2n1d
nda8d
n2d1ak
n6d5a6ns
n1de
n2d1ei
nde1la
nde8lac
nde2ls
ndel6sa
nder1h8
n8derhi
nde4se
nde1sta
nde8stal
n2d1j
n2d1n6
nd1ni6
ndn6is5
n1do
n6d5o2r6t
ndr4
nd3rec
nd3rot
n2ds
nd1sa
nd1sam
nd8sa2m1t
nd6sau
n2dt
ndt1h
n1du
n8du2m1d
1ne
ne5as
ne1b
ne2bl8
6n5e2b1n
2nec
5ne1ei
ne5en
ne1g4l
2n1egy
4n1ein
8neis
ne1le
4n3e4lem
8ne2m1b
2n1e2mp
nen1a
1ne1ne
6n5e4ne8r1g
nen3k
8nen2t1b2
4n3en3th
8nen2t1l
8n5en2t1n
8n5en2t1s
ne1ra
ne5r8al
ne8ras
ner1b
8ner1bi
ne8rd
ner1de
6n5erde.
ne1re
n2erei
nere5i6d
ner1f
ner1fo
nerfor6
ner1h8
6n5erhö
ner1l
8nerlö
2n1e2rr
ne2r1s
n8ers.
ne2r1t
nertr6
6n5ertra
2n1erz
ne1si
nesi3e
net1h
neu4ra
neu5sc
8neuß
n1f
n2f5f
nf2l
nfl8e
nflei8
nf1li
nf5lin
n2ft
nf2ts
nft8st
n1ga
n8g5ac
n6g5d
n1ge
ng8en
nge1ra
nge8ram
n2g1g2
ng1h
ng1li
n6glic
n1gr4
ng3r2ip
ng8ru
n2gs
ng2se4
ng2si
n1gu
n2g1um
n1gy
n1gä
n8gäl
n1h
nhe6r5e
1ni
ni1bl8
nic8h
ni5chä
ni1d
ni1de
ni8de1e
n6ie
ni1en
nie6s5te
niet5h
ni8e2t1n
n2i1ge
4n3i6gel
n6i1k
n2il
ni1la
2n1i2mp
ni5na
2n1i2n1d
8nin1f
6n5in1h
1ni1ni
ni8nit
6n5inn
2n1i6ns
4n1int
n6is
nis1tr6
ni1th
ni1tr6
n1j
n6ji
n1ka
n8ka1d
nk5a6ns
n1ke
nker1l
n8kerla
n1ki
n6k5in1h
nkl8
n5klö
n1k2n8
n8k5not
n1kr8
nk3rot
n8krü
n2ks
nksp2
nk5s1p2o
n2k1t
nk6t5r6
n1ku
n8kuh
n1kü
n6küb
n5l6
n1li
nli4mi
n1m
n1me
nme6n4s
n1na
n1ne
n8ne8r1g
n1ni
nn2i5o
n1no
nn1ta
nn4t3ak
nnt1h
n1nu
nnu1e
n1ny
n1nä
n1nö
n1nü
no5a
no1bl8
no4b3la
4n3o8bs
2no2b1t
noc8h
no1che8
no1d
no1di
no6die
no4dis
no8ia
no5isc
no1le
6n5o6le3u
no1ma
no4mal
n8o1ni
non6ie
noni6er
2n1on1k
n1ony
no1pe
4n3o4p8er
6nopf
nop1t
6n1opti
no3ra
n1o4ram
no8rd
nor6da
4n1o8r1g
2n1o2r1t
n6os
no1st
8no2st.
no1ta
no8tan
no1te
no8ter
no1ty1
noty6pe
6n5ox
n1p2
n1q
n1r
nrös3
6ns
n1sac
ns3ang
n1sc
n1se
n8sel1f
n8s5er1f
n8se8r1g
n6se6rk
ns5er1w
n1si
n8sint
nsp2
n1s2pe
n1spr6
n1sta
n6s5tat.
n1sto
n6stob
n1str6
n1ta
n1tag
n4t3a4go
nt5an1h
n2t3a6rk
n2t3a2r1t
n1te
n4t3eis
nte5n6ar
nte1ne
nte8nei
nter3a
nte1re
nt2e6rei
nt1h6a
nt6har
n3ther
nt5hie
n3thus
n1ti
nti1c
n8tin1h
nti1t
n2t1l
ntlo6b
n2t1m8
nt1me
ntmen8
n1to
n2t3o4ti
n1tr6
ntra5f
ntra5ut
nt8rea
n2t3rec
nt8rep
n4t3rin
nt8rop
n4t3rot
n4trü
n2t1s
nts6an
nt2s1k2
n1tu
n2t1z
n1tä
n1tö
n8töl
n1tü
1nu
nu1a
nu5el
nu5en
4n1u6hr
n6ui
nu5ie
8nu2m1l
6n5u2ms
6n5u2m1w
2n1u2n1d
6nu1ni
6n5un1r
2n1unt
2nup
2nu6r
n5u1ri
nus1k2
nu3s1kr8
nu5ta
n1v
8n1w
1nys
n1za
n6z5a6b
n2z1ar
n6zaus
n1zi
nzi4ga
n1zo
n8zof
n1zu
n6z5unt
n1zw8
n1zwi
n6zwir
1näc
5nä1e
5n6äi
n8äl
nä6m
nä6re
n5ärz
5näus
n1öl
1nöt
n5ö2z
5nü.
6n1ü2b
5nüß
o5ab.
oa2l
o8ala
o1a2m
o1an
o1ba
ob1ac
o1be
obe4ra
o6ber1h8
5o4be2r1s
o4b2e1ru
obe1se
obe6ser
1ob1j
o1bl8
o2b1li
o8bs
ob5s1k2
3ob2st.
ob8sta
obstr6
obst5re
ob5s1z
oc8h
o1che
oche8b
o8chec
o3chi
och1l6
o6ch3m
ocho8f
oc6hr
o3chro
o2cht
och3to
o3chu
o8ch1w
o1d
o2d1ag
o2d1d
od2dr4
o1de
ode5i
ode6n5e
o2dt
od1tr6
o5e6b
oe1d
oe1de
o5e6der.
oe8du
o1e1f
o1e2l
o1e2p
o1er.
o5e8x
o1fa
o2ff
of1fa
of8fan
1of1fi
of8fin
of6f5la
o5fla
o1fr6
8o1g
og2n8
o1ha
o1he
o6h5eis
o1hi
ohl1a
oh1le
oh4l3er
5ohm.
oh2ni
o1ho
o6hr
oh1re
oh1ru
o1hu
oh1w
o1hy
o1hä
o5ia
oi1d
o1id.
o8i1di
oi8dr4
o5i2ds
oisc8h
o5i8s2ch.
oi1se
oiset6
o1i2s1m
o3i2st.
o5i6tu
o1j
o1k
ok2l8
o1kla
ok3lau
o8klä
o2k1t
1okta
o1la
o6ld
old5am
old5r4
o1le
ole5in
o1le1r
ole3u
o2l1g
ol6gl
o6l1k
ol2k2l8
ol2k4s1
o6ll
ol1la
ol8lak
ol8lauf.
ol1le
ol6lel
ol8less
o1lo
o2l1s
ols1te
ol2ster
ol6s1k2
o1lu
o1ly
oly1e2
5olym
o1ma
o2mab
o3m6an
o8mau
o2m1b
om1be4
o1me
o8merz
o2ms
om5sp2
o1mu
o1mun
o8munt
o1mä
o1mö
o1na
ona8m
o2n1a1x
o1ne
on8ent
o6n5er1b
8o1ni
on6ie
oni5er.
on1k
on1na
on6n5a6b
o1no
ono1c
ono1k
o4no2k1t
1o6ns
on2t1s8
o1nä
oo8f
1o8o1g
oo2pe
oo2sa
o1pa
o1pe
op8er
3o4pe1ra
opf2l
o3pf1li
opf3lo
opf3r6
o1pi
o1pl8
o2p1li
o5p6n
op8pa
op6p1l8
o1pr6
op1t
o3p4ter
1opti
o1pä
o5pö
o1q
o1ra.
o3ra1d
o8ra2d1d
1oram
o6rang
o5ras
o8rauf
orc8h
or5cha
o8rd
or1da
or4d3a4m
or1de
or8dei
or8deu
1or2d1n6
or1do
or4dos
o1re
o5re.
o2re2h
o8r5ein
ore5isc
or6enn
or1f
or8fla
or8f1li
o8r1g
1or1ga
or1ge
5orgel.
or2gl
o1ri
or2ie
ori1en
5o6rient
o2rn
or1na
or8nan
or8nä
o1ro
o2rr
or1r2h8
o2r1t
or6t5an
or8tau
or8te1re
o1r6us
o1ry
o1rä
or1ü2
o1sa
o1sa3i
6o1se
o8se6rk
o1s1k2
o6ske
o6ski
os2kl8
os2k2o
os2kr8
os1n
os1ni
osn6i5e
o1so
o2s1o2d
osp2
os1pe
o3s4p8er
o1sta
o4stam
o6stau
ostr6
o3stra
ost3re
o1su6
o6s5ur
os1z
o5s6ze
o1ta
ot3auf
o6taus
o1te
o6ter1w
o1th
othe5u
o2t6h1r6
o1ti
o1to
oto1a
otr6
ot1re
o1tri
o1tro
o2ts
ot1sc
o3t1su
o2t1t
ot6t5e8r1g
ot2t3h
ot2t5r6
ot8tö
o1tu
ou3e
ouf1
ou5f6l
o5u6gr4
o6ui
ou5ie
ou1ra
ou6rar
ou1t6a
o1v
o1wa
o1we
o6wer.
o1wi
o1wi1d6
o1wo
o5wu
o1xe
oy5al.
oy1e
oy1i
o5yo
o1z
oza2r
o1ze
1o2zea
o1zo
ozo3is
oö8
o1ße
oß5e2l1t
oß1t
3paa
pa6ce
5pa1d
pag2
1pak
pa1la
pa8na8t
pa1ni
pan6ie
pani5el
pa1no
pa4nor
pa6n1s2
1pap
pap8s
p2a1re
pa8rei
pa6rk
par8kr8
par2o8n
par5o6ti
pa2r1t
part8e
5p8ar5tei
3par2t1n
pa2s1se
pas6sep
pa1th
pa4th6a
1pau
6paug
pau3sc
p1b
8p5c
4p1d
1pe
4peic
pe5isc
2pek
pen3k
pen8to8
p8er
pe1ra
pe1re6
per5ea
per5e1b
pe4rem
2pe2rr
per1ra
per8ran
3pe2r1s
4per1si
pe3rü
pe4sta
pe2t2s
p1fe
p2f1ec
p4fei
p2f1f
pf2l
5pf8lanz
pfl8e
pf8leg
pf3lei
2p2ft
pf3ta
p1g
1ph
2ph.
2p1haf
6ph1b2
8ph1d
6p5heit
ph5e1me
6ph1g
phi6e
8ph1k2
6phn
p5ho6ll
pht2
ph3th6a
4ph3t1he
phu6
6ph1z
pi1en
pi5e2rr
p2il
pi1la
pi1na
pi6ns
5pin1se
p2io
pi8o1ni
pion6i8e
1pis
pi1s2k2
pi1th
p1k
pl8
5pla
p2lau
4plei
p3lein
2p1ler
6p5les
p1li
2p3lig
p6li1k
6p5ling
p2li1z
plo1mi
plo8min
6p1m
p1n
1p2o
8poh
5pol
po1la
po8lan
po1ly1
po3ny
po1ra
2po2rn
po2r1t
por4t3h
po5rö
5po1ti
p1pa
p1pe
p6p5ei
ppe6la
pp5f
p2p1h
p1pi
pp1l8
ppp6
ppr6
pp5ren
pp1s
p2pst
pp2s1te
p5pö
pr6
3preis
1pres
2p3r2ig
5prinz
1prob
1pro1d
5pr8o1g
pro8p1t
pro6t5a
pro1te
prote5i
8proß
prä3l
1präs
prä1te4
1prüf
psc8h
p5schl6
2pst
1p2sy
p1t
p8to8d
p2t1s
5p6ty1
1pu
pu1b2
2p2uc
pu1d
pu2dr4
pu2ff
puf8fr6
6p5uh
pu6n8s
pu1re
pu8rei
pu5s6h
pu1ta
p1v
p3w
5py
py5l
p1z
pä1de
pä6der
p5ä6m
pä8nu
8pär
pät5h
pä2t1s
qu6
1q6ui
8ra2b1k2
ra1bl8
ra6b1la
3rable
ra2br
r1a2b1t
6ra8b1z
ra1d
ra4dan
ra2dr4
r8afa
5ra3fal
ra1fe
ra4f3er
ra5gla
ra2g3n8
6ra1ha
ral5am
5ra6ld
4ra2l1g
ra1li
ra8li6ns
2ra6ll
ra2l5t
ra1me
8ramei
r3anal
r6a2n1d
ran1de
ran8der
ran4dr4
8ran1f
6ran1ga
5ran1gi
ran8g1li
r3an1gr4
ra6ns
ransp2
rans5pa
8ra8n1w
r8anz.
ra5or
6rapf
r8a5pl8
rap1se
rap6s5er
2r1ar1b
1rar1h8
r1a6r1m
ra5ro
2r1a2r1t
6r1arz
ra1te
ra8tei
ra1th
ra6t5he
6ra2t1l
r4a1tr6
ra4t3ro
ra2t1t
r5atta
rau1e
raue4n
6raus.
r5au4sta
rau1te
rau8tel
rau2t5s
ray1
r1b
rbl8
rb5lass
r6b1ler
rb1li
rb4lie
r1bo
rbon6n
r1br
rbrec8h
r8bre2cht
r8bs
rb6s5tä
r1ce
r8ces
rc8h
r1che
rch1l6
r6ch3m
rc6hr
rch3re
r2cht
rch3tr6
r8ch1w
8rd
r1da
r1dac
rdac8h
r8da2chs
r8d1ap
rda5ro
r1de
rde5i6ns
r1di
rd2io5
r8dir
r1do
rd3ost
r1dr4
r8drau
1re.
re1ak
3re1a2k1t
re3a2ls
re1am
re6am.
re1as
re1b
re1be
4reben
re6bl8
rec8h
rech5a
re1d
r8e1di
re3er
re1f
8re2ff
3refl
2reh
5re1ha
r4ei.
reic8h
rei2ch6s5
rei1e
8reier
6r1eign8
re5i2mp
4r3ein1a4
6r3ein1b2
6rein1g
6r5einn
6rein1r
4r3ei6ns
r3eint
re1li
reli3e
8r5e2l1t
re2mp
6r1emp1f
2re2m1t
ren5a6b
ren8gl
r3en1ni
1re1no
5ren1te
4r3enth
8ren2t1l
4r3en2t1w
8r1en2t1z
ren4zw8
re1on
re1q
requ6
re1q6ui5
1rer
rer1b
rer4bl8
6rer8bs
4r3e8rd
rer1h8
8rerhö
re6rk
8rer1kl8
rer1l
4r3erla
8rerlö
re2rn
4r3er6ns
6r5er1nä
rer5o
re2rr
rer1re
6r5erreg
re2r1t
r5ertr6
rer1w
r5erwec
r5erö8
re2sa
re1sc
resc8h
re8s6ch2m
2ress
re5u8ni
re1w
6rewo
2r1ex
r1f
r1fe
r8fe8rd
rf1li
rf4lie
8r1g
r1ga
r8gah
r1ge
rge1b
rge4bl8
rge5na
rge1s
rgest4
rgn8
rg6ne
r2g1ni2
r1go
r8gob
r1gr4
r4g3ret
r2gs
rg1se
rg8sel
r1h8
r2hy
5rhy1t
ri1ar
ric8h
ri5cha
ri1d
ri2d2g
r2ie
rie2g4s5
ri8ei
ri1el
ri6e1le
ri1en
ri3er.
rie2r1s
ri5ers.
r2if
ri1fa
ri6fan
ri1fe
ri8fer
ri8fr6
1r2ig
ri1k
ri8kn8
r2il
ri5la
ri1mä8
ri1na
ri2n1d
r8in1de
rin4ga
rin6gr4
1rinn
rin1ne
6rinner
ri1no1
ri6ns
r8in1sp2
4rinst
ri1nä2
r2io
rio1c
ri5o6c8h
ri1o2d
ri3o6st
2r1ir
r2is
ris1k2
ri3s1k2o
risp2
ri8spr6
ri5s1v
r2it
ri1ta
6r5i6tal
ri5tr6
r2i1v
ri1ve
ri6ve.
8r1j
6rk
r1ke
rke6hr
rkeh2r6s5
r1ki
rkl8
rk1li
r3k2lin
r1k2n8
r2ks
rkst8
rk3str6
r2k1t
rk4t3an
rk6to
r1ku
r6kuh
r1kä
rkä4s3t
r1l
r5li
rli1ne
rline5a
6r1m
r1ma
r3man
r6m1an5l6
rma4p
r4m3a1ph
r1mi
r8min1f
r1mo
r8mob
r2ms
rm5sa
2rn
r1na
rna8be
r5ne
rn2ei
r6ne2if
r6nex
r6n1h
rn1k
r1no
r6n5oc
r6ns
rn1sp2
r1nä
r1nü
ro1be
ro6be2rn
6ro8bs
ro1c8h
roc2k
3ro2ck.
ro1d
ro5de
ro1e
4ro1fe
ro1he
ro8he2r1t
1ro6hr
ro5i1d
ro1in
ro5isc
ro1ly
6r5olym
r2on
6r1o8o1g
ro1ph
ro6phan
r3o2r1t
ro1s2p2
ro5s6w
ro1ta
ro4tau
ro1tr6
ro6ts
5rout
r1p
r1pe
rp8er
rpe8re6
rp2f
r2ps
r2p1t
r1q
2rr
r1ra
r1re
r1rer6
rr1h8
rr6hos
r5rhö
r1ri
r1ro
rro8f
rr8or
rror5a
r1ru
r3ry
r1rä
r1rö
r1rü
2r1s
r2s1te
r2s1ti
r6sab
r4san1f
r1se
rse6e
rse5na
r2s1h
rs1k2
r6s1ka
r6ski
rs2kl8
r8s1k2o
r2s1l
rs2p2
r1sta
r6stauf
r8ster1w
rstr6
r8stran
r2s1w
rs1wi3d4
r2s1z
2r1t
2r2t3a2r1t
r8taut
r5tei
rt5e2i1ge
r8te1pe
r4t3er1h8
rter1l
r8terla
r4t3hei
r5t6hu
r4t3int
rtr6
r4t5re2if
r2ts
rt1sc
rt1se
rt6s1er
rt6s5o
rt6s5u
r6t5u2n1d
2r8tu2r1t
ru1be6
ru1en
1r4uf
ru2fs
ruf4st
r6ui
ru1ie
2r1u2m1g
2r1u2m1l
2ru2ms
ru2n1d
run1de
run8der
run4d5r4
6run2d1z
6run1f
8ru6ns
2r1unt
2r1ur
r6us
ru6sta
rus1tr6
ru6tr6
1ru2ts
r1v
r1ve
rven1
rvi2c
r1w
r1x
r1za
rz5ac
r6z5al
r8z1ar
r1ze
r8ze8rd
r6z5er1f
rz8er1h8
r2z1t
rz4t3h
r1zu
r8zum
rä4s1te
räu8sc
r1öf
5rö6hr
rö5le
3rö6ll
rö1mi
5römis
r1ör
rö2sc
3rü2mp
1sa.
1saa
sa1be
s3a4ben
sa2bl8
2s1a8b1s
6s1a2b1t
6s1a2b1w
sac2k
3sa2ck.
sa1d
sa1de
6s3a4der
1saf
s8a1fa
4s1a2ff
sa5fr6
1sag
1sai
sa1i2k1
4s1a2k1t
1sal
sa1la
sa6l1p
4s3alpi
sa2l1t
6salter
salz3a
1sam
s5an1b2
san2c
1sa2n1d
san1ge
s5angeh
6s1an5l6
2s1a6ns
6s3an1tr6
8s1a8n1w
s1ap
s6a1ph
8sa1p2o
sap5p6
s8ar.
2s1ar1b
3sa8r1g
s1a6r1m
sa5ro
2s1a2r1t
6s1arz
1sas
1sat
s8a1t8a
2s1a2t1l
sa1to
sa8tom
3s8au1e
s5au2ff
sa6u5i
s6aur
2s1aus
5s6au1se
2s1b2
2s1ca
s4ce
sc8h
8s2ch.
3scha.
scha1d
5scha1de
3schaf
3schal
sch5a1me
8schan1c
8s6ch1b2
1sche
6s1che1f
8schex
2s6ch1f2
2sch1g
2s4ch1h
1schi
2sch1k2
schl6
5schlag
5schlu
s6ch2m
6sch3mäß
s2chn6
6sch1n8aß
1scho
6scho8rd
6s6ch1p
sc6hr
3schri
8sch1ric
8sch1r2ig
8schrou
6s2chs
2s2cht
sch3ta
sch3tr6
1schu
8s6ch3unt
6sch1v
2sch1z
5schö
5schü
2s1c8o
s1c6r
scre6
6s1cu
2s1d
1se
se5an
se1ap
se1b
se1be
se6ben
se5ec
se1ei
see5i6g
se3er1l
se1f
8se2ff
se1ha
se6han
se8hi
se8hö
sei1d
6s5eid.
2s1eig
s8e2il
5sein.
sei5n6e
6s5ein1h
3s8eit
3sel.
se1la
se4lar
se2lb4
se1le
6s3e4lem
se1ler
se8ler1l
2s1e2mp
sen3a2c
se1ne
se5nec
6s5en2t1s
4s1en2t1z
s8er.
se1re
s2erei
se8reim
s2e1ri
se1r5inn
se6r1m
8sermä
8s5er1zi
serö8
6ser1öf
se1um
8sexa
6s1e8x3p2
2s1f2
sfa6ll
sfal1le
sfal8ler
2s3g2
s1ge
sge5b2
s1h
s8he1w
5s6h2ip
5s4hop
1si
2siat
si1b
sic8h
si2cht
sich2t6s
si1d
si1de
6s5i6de1e
sie1ge
siege6s5
si1en
si5e2rr
s2i1f2
si1g2n8
si6g5r4
si1k
si1ka
si8kau
sik1i
si4kin
si2kl8
si8kü
s2il
si1la
si2lb
sil6br
si1na
2s1in1f
sin5g1h
2s1in1h
sin1ne
sinne6s5
2s1i6ns
si5ru
si5str6
4s1j
s1k2
6sk.
s1ka
2skau
ske8l6c
skelc8h5
s6ke1le
1s2ki.
3s4kin.
s6ki1z
s8kj
6skn8
s1k2o
2s3kow
s1kr8
3s2krib
3s2kr2ip
2s1ku
8s1kü
s1l
s8lal
slei3t
s4low
2s1m
s1n
6sna
6snot
1so
so1c8h
so1d
2s1o1do
so4dor
so1fe
6s5o4fen
so1lo3
s2on
so5o8f
4so1pe
so1ra
2s1o8rd
so8r1g
4s1or1ga
so2u5c
so3un
4s3ox
sp2
8s3paa
5spal
1span
2s1pap
s1pe
s2pec
s4peis
1s2pek
sp8er
s6pe8r1g
4s3pe2r1s
s6pes
2s1pf
s1ph
8sphi
1s2phä
1spi
spi4e
6s5pig
spi6ns
6s5pin1se
2s1pis
spl8
2s5pla
s1p2o
2s5pol
5s6pom
6s5pos
6s5po1ti
spr6
1spra
3s8prec
6s3preis
5spring
6s1prob
1spru
s1pu
s2pul
1s2pur
6s5py
5spän
1spü
s1q
2s1r
2ssa
2s1se
2s1si
2s1so
2s1sä
2ssö
2ssü
2s1sc8h
sse8nu
ssi1ni
ssin6i6s
ssoi6r
2st.
1sta
4s1ta1fe4
2s1tag
sta3la
6s1ta1le
4s2ta2l1g
8sta6l1k
8s2t1a2m1t
6st5an1f
4st3a6ns
6st5a8n1w
6star1b
sta4te
6staus
2s2t1b2
6s2t1c
6s2t1d
s1te
4s1te2il
3s2tep
6s5tep1pi
8ste2s1se
6s2t1f2
2s2t1g2
2sth
st1h6a
st3hei
s8t1hi
st1ho
st5hu
s1ti
s2ti4el
4s2ti2g1m
6s2t1i2n1d
4s2tin1f
s2ti8r
2s2t1k2
2s2t1l
2s2t1m8
1sto
sto6ll
6s5toll.
4st3o1pe
6s5topf.
6sto8rd
6s2t1p2
str6
4s1trai
s3tral
6s5tr6aum
3str8aß
3s2trec
6s3tre1f
8s3treib
5s4tre2if
6st1re1no
6stres
6st3re1v
2s2t5r2ig
8s2t1r2is
s8tro1ma
st5r6o1se
4st1r4uf
3strum
6s1träg
2s2t1s6
2s2t1t
1stu
stu5a
4s1t2uc
2s1tu1e
8stun.
2s2t1v
2s2t1w
s1ty1
s2tyl
6s2tz
1stä
8s5täg
1stö
1stü
8s5tüc8h
4s1tür.
1su
su2b1
3s2uc
su1e
su2fe
su1ma
su8mar
su2m1f6
6sumfa
8su2m1k8
2s1unt
sup1p2
su1ra
6s5u6ran
su2r1t
6surte
2s1v
2s1w
1sy
8syl.
sy5la
syn1
sy2na
sy1ne4
s1z
s1ze
s4ze2n1d
sze1ne
5s6z4ene.
8s1zu
1sä
6s5ä2n1d
s1äug
6säu1gi
6s1äuß
5söm
2s1ü2b
1süc
sü8di
1sün
5süß
taa2t2s3
4tab.
t6a1ba
taba6k
ta8ban
ta1b2l8
ta1br
ta6b1re
4ta8b1s
t3ab1sc
8ta8b1z
tac8h
6t3a2cht
ta1d
ta1de
ta6der
6tadr4
ta2d6s
ta2d2t1
1ta1fe4
1tag
ta6ga6
ta1ge
ta8gei
tage4s
ta2gs
tag6s5t
tah8
tahl3
tai1ne
tai6ne.
ta5ir.
ta2k1t
tak8ta
tal3au
1ta1le
ta8leng
ta1ler
ta6l5e2r1t
ta1me
6t5a6mer
6ta2mp
tam1pe6
2t1a2m1t
ta2n1d
tan5d6a
tan8dr4
tan2ds
tand1s5a
ta1ni
tan6i5e
6t1an5l6
2t1an1r
t3a6ns
8t5an1tr6
ta1nu6
t5a8n1w
8tanwa
tan8zw8
ta1ra
ta8rau
tar1b
6tar1be
1t2a1ri
2ta6rk
2t1a6r1m
ta1ro
2ta2r1t
t3arti
6tarz
ta1sc
ta1si
ta6si1en
tas1te
ta8stem
ta8s1to
t5au2f1b2
4t1au2f1n
8taus.
5tau1se
8t1au2s1f2
6t1au2s3g2
t5au8s1l
2t1b2
2t1c
tc8h
t6chu
2t1d
te2am
tea4s
te1b
te1be
te8ben
tec8h
5t8e2ch3n6
te1f
4te2ff
te1gr4
te4g3re
te1ha
te6hau
2te1he
te4hel
2t1e6hr
tei1d
te5id.
teig5l
6t1eign8
tei8gr4
1te2il
4tein1h
t5einhe
4teis
tei1se
t5eisen
8tei1w
te1la
te8lam
te4lar
te1le
4t1elek
8telem
te1ma
te6man
te6n5ag
te1ne
ten8er1w
ten5k
te6ns
ten1s4p2
ten1tr6
ten8tro
4t3en2t1w
8t1en2t1z
te1pl8
te6p1li
5tep1pi
ter5a6b
te3ral
ter5au
ter1b
ter1ba
8terbar
ter1be
t5erbe.
6terben
8ter8bs
4t3er2b1t
te8rd
ter1de
t5erde.
te1re
tere1b
ter5e1be
t2erei
ter5ein
te1rer
te8re2r1s
ter1f4
ter1h8
8terhö
te6rk
ter1kl8
6t3er1klä
te2rn
ter1no
ter8nor
te2rr
ter1re
ter6re.
te2r1s
tersc8h4
t8erscha
te1se
t5e6sel
te2s1ta
te8stau
t3eu1ro
te1xa
tex3e
8t1e8x3p2
te8x1t
tex6ta
2t1f2
2t1g2
2th.
th6a
5tha.
2t1haa
6t1hab
6t5haf
t5hah
8thak
3t2hal.
6tha2ls
6t3ha2n1d
2t1hau
1the.
3t4hea
t1he1b
t5he2il
t3heit
t3hel1f
1t8heo
5t4he1rap
5ther1f
6t5herz
1thes
1thet
5thi.
2t1h2il
t3him
8thir
3this
t5h1j
2th1l
2th1m
th1n
t5hob
t5hof
4t1holz
thop1t
6th1opti
1t6hr6
4ths
t1hum
1thy
4t1hä
2t1hö
t1hü
ti1a2m
ti1b
tie1f
tie1fe
tie6fer
ti1en
t2i1ge
ti8gerz
tig3l
ti1k
ti8kin
t2il
ti5lat
1ti2l1g
t1i2n1d
tin4k3l8
tisp2
ti3spa
ti5str6
5ti1te
ti5tr6
t2i1v
ti1ve
ti8vel
ti8vr
2t1j
2t1k2
2t1l
tl8a
2t1m8
2t1n
3to1be
8t1ob1j
toc8h
to3cha
5to2cht
8toc2k
to1d
to1de4
to8del
to8du
to1e
to1fe
6t5o6fen
to1in
toi6r
to6ll
5toll.
to1me
to8me1ne
t2o6ns
2t1ony
to1pe
to4p8er
5topf.
6top1t
to1ra
to1s
to2s1te
to1s1k2
to6s1ka
tos2l
2to1ti
to1tr6
t8ou
2t1p2
6t1q
tr6
trac8h
tra5cha
tr8afa
tra8far
tra2f5t
1trag
tra6gl
tra6gr4
t3rahm
1trai
t6ra6ns
tra3sc
tra6st
3trau1e
t4re.
2trec
t3rec8h
t8rec2k
6t1re1d
t8ree
4t1reg
3treib
4tre2if
8t3reis
8tre1p2o
tr6e6t5r6
t3re1v
4t3re1z
1trib
t6ric2k
tr2ie
tri6er
2t1r2ig
t8rink
tr2io
tri6o5d
tri1z
tri1zi5
tro1a
3troc
troc2k
trocke6
tro5i8d
tro1ma
tro3m6an
tro8man.
tr2on
tro3ny
5tropf
6t5ro1sa
t5roß
5trub
5trup
trut5
1träg
6t1röh
5trüb
tr5ü3bu
t1rüc
t1rüs
2ts
ts1ab
t1sac
tsa8d
ts1ak
t1sal
t6s5a2l1t
ts1an
ts1ar
ts3auf
tsc8h
t3sc6hr
t5schä
t1se
tse6e
tse1e5i
tsei6n6s
ts3ent
ts1er
t8ser1f
t4se6rk
t8s1h
t1si
5t6si1k
t4s3int
t1so
tso2r1t
ts5ort.
tsp2
ts1p2o
t5s6por
tspr6
t6sprei
t1st
t2s1te
t1sta
t6s5tanz
t2s1th
ts1ti
t6stit
t1sto
t4s3tor
t1su
1t2sua
t2s1uf
t8sum.
t2s1u8n
t2s1ur
2t1t
tt5e2if
tte6sa
tt1h6a
ttr6
tt8ret
t2ts
tt1sc
tt1se
tt8s1er
tt5s6z
1t2uc
tuc8h
tuch5a
1tu1e
6tuh
t5u6hr
t6u1i
tu6it
1tu2m1h
6t5u2m1r
1tu2ms
8tu2m1t
6tu2n1d
6tun1f
2t1unt
tu5ra
tu6rau
tu1re
tu6re.
tu4r3er
2t1v
2t1w
1ty1
ty6a
ty8la
8tym
6ty6o
2tz
tz5al
tz1an
tz1ar
t1ze
t8zec
tzeh6
tzehn5
t6z5ei.
t1zo
t6zor
t1zu
t4z3um
t1zä
t6zäu
5täg
6täh
t5ä2l1t
t8än
tä1re8
8tä8st
6t1äuß
tö2ff
töf5fe
t5öffen
8tö8k
1tön
4tüb
tü1b6e2
t3ü4ber1
t6ü5b8er.
5tüc8h
1tür.
u3al.
u5a2lb
u5al1f
u3a6l1h
u5a6l1k
u3a6l1p
u3an.
ua5na
u3a2n1d
u5a6ns
u5ar.
ua6th
u1au
ua1y
u1ba
u2bab
u1bi
ub6ie
ubi5er.
u1br
u6b5r2it
u8bs
ubs2k2
u5bö
u1bü
u8büb
2uc
uc8h
u1che
u6ch5ec
u1chi
uch1l6
u6ch3m
u2ch5n6
uc6h1r
u2cht
uch5to
uchtr6
ucht5re
u1chu
u8ch1w
uc2k
uc1k1a
uck5in
u1d
ud4a
u1ei
u6e1la
ue1ne8
u6ep
u1er
uer1a
ue1re
ue1rer
ue8rer1l
uer5o
u8e1sc
u2est
u8e1v
u1fa
u1fe
u2f1ei
u4f3ent
u8fer1h8
u2ff
uf1fr6
uf1l
ufr6
uf1ra
uf1re
uf1rä
uf1rü
u2fs
uf1s2p2
uf1st
u2ft
uf2t1s
u1ga
u8ga2b1t
u8ga1d
u6gap
u1ge
uge1b8
u8gn8
u1go
ugo3s4
u1ha
u1he
u1hi
uh1le
u1ho
u6hr
uh1re
u1hu
uh1w
u1hä
u1hö
6ui
ui5en
u1ig
u3i6ns
uin1te
uin8tes
uisc8h
u5i8s2ch.
u1j
6uk
u1ke
u1ki
u1kl8
u8klu
u1k6n8
u5ky
u1la
u6ld
ul2ds
uld8se
u1le
u6ll
ul1la
ul8lac
ul6lau
ul1le
ul6le6l
ul6lo
u6ln
ul1ni8
u1lo
ulo6i
u2l1t
ult6a
ult8e
u1lu
ul1v
ul2vr
u1lä
u1lö
u2m1f6
3umfan
u2m1l
5umlau
u1mo
u8mo8f
u2mp
um1ph
um8pho
u1mu
umu8s
u5mö
u1n1a
un2al
un6at
unau2
u2n1d
6und.
un1de
un2d1ei
5undein
un1du
un4d3um
un2d1z
3undzw8
un1dü8
un8düb
u1ne
une2b
u2n1ec
une2h
u8n3eis
un1f
3unfal
1un1fä
un1ge
5unge1a2
3un1glü
un2g2s1
un8gä
u1ni
1u2n2if
un4it
un1kr8
un8kro
un2k5s
u1no
un1p2
unpa2
u6ns
uns2p2
un1v
unvol4
unvo6ll5
u5os.
u1pa
u1pi
u1p2l8
u1pr6
u2p4s3t
up1t
up2t1a
u1q
u1ra
ur5a8b1s
ura8d
ur5ah
u6rak
ur3a2l5t
u6rana
u6r5a6ns
u8rap
ur5a6ri
u8ra2t1t
u1re
ur3eig
u8r1g
ur1gr4
ur8gri
u1ri
ur5i6ns
ur1l
3urlau
u6r1m
ur1me
urmen6
u2rn
ur1na
ur8nan
u1ro
u2r1s
3ursac
ur8sau
ur1se
ur8sei
ur4s1k2
u2r1t
3ur5tei
u1ru
ur6u5i6
u2r1u6r
u1ry
ur2za
ur6zä
ur5ä6m
u5rö
u1rü
urü8c2k3
u1sa
u1sag
usa4gi
u2s1ar
u2s1au
usc8h
u1sche
u8schec
us8chw
usch5wi
u1se
u2s1ei
use1ke
use8kel
u8s1l
u1sta
u4st3a4b
us3tau
u1su
u2s1uf
u8su2rn
ut1ac
u1tal
uta8m
u1tan
ut1ar
u1tas
ut1au
u1te
u8teic
u4tent
u8ter1f4
ut2e1ri
u6terin
u4t3hei
ut5ho
ut1hu
u1ti
uti1ne5
uti6q
u1to
uto5c
u1tr6
u2ts
ut1sa
ut1s6p2
ut1st
utstr6
ut6stro
u1tu
u2tz
utz5w8
u1u
u1v
u1ve
uve5n
uver1
uve3r4ä
u1w
u1xe
u5ya
uy5e6
u1yi
u1ze
u2z1eh
u8zer1h8
u5ö
u1ße
uße6n
uße1n5e
8van1b2
6vang
6var1b
va8r8d
v8a6t5a
va1te
va8tei
v4a2t1r6
2v1b
6v5c
6vd
1ve
6ve5g6
ver1
ver5b
verb8l8
ve2re2
ve8r1g8
v2e2ru8
ve1s
ve2s3p2
ve3xe
2v1f
2v1g
6v5h
vi6el
vie6w5
vi1g4
v2il
vi1le
vi8le8h
vi6ll
vil1le
vil6le.
8vint
vi1ru
vi1tr6
2v1k
2v1l
2v1m
4v5n
8vo8f
vo2il
voi6le
vo6ll
vol1le
vol8le2n1d
vol8li
v2or1
vo2re
vo1ri
vo8rin
vo2ro
2v1p
8vra
v6re
2v2s
2v1t
2v1v
4v3w
2v1z
wa2ff
waf5fe8
wa6g5n8
1wah
wah8n
wa5la
wa6ld
wal1di
wal8din
wa2l1t
wal6ta
wa2n1d
wan4dr4
5w2a1re
wa8ru
war4za
1was
w5c
w1d
5wec8h
we1f
we6fl
1weg
we1ge
we8geng
weg5h
weg3l
we2g1r4
we6hr
weh1re
weh6r5er
5wei1se
weit3r6
we2l2t
welt3r6
we6rat
8wer1c
we8rd
5wer1du
wer1f
wer4fl
we6rk
5werk.
wer4ka
wer8ku
we2r1t
wer4ta
wer8te6r1m
we2sp2
wes1te
we8s4te2n1d
we8str6
we8stö
we2t1t
wet8ta
wic8h
wi2chs
wich6s5t
1wi1d
wi2dr4
wie1d
wie1de4
wieder5
wi1k6
wi2m1m
wim6ma
wi2n1d
win4d3r4
5wi2r1t
wisc8h
wisch5l6
1wj
6wk
2w1l
8w1n
wo1c
woc8h
wo1che6
wol6f
wo2r1t
wor6t5r6
6ws2
w1s1k2
6w5t
wu2n1d
wun1de
5wunde.
wun6gr4
wu1sc
wu2t1
6w5w
wy5a
wä6r1m
wär1me5
wä1sc
1xag
x1ak
xa1me
x3a4men
8xa2m1t
x1an
8x1b
x1c
1xe.
x3e4g
1xen
xe1ro
x1erz
1xes
8xf
x1g
8x1h
1xi
8xi1d
xi8so
4xis1te
x1k
6x1l
x1m
8xn
1xo
8x5o6d
8x3p2
x1r
x1s6
8x1t
x6tak
x8ter1f4
x2t1h
1xu
xu1e
x5ul
6x3w
x1z
5ya.
y5an.
y5ank
y1b
y1c
yc8h
y6cha
y4chia
y1d
yen6n
y5e2rn
y1g
y5h
y5in
y1j
y1k2
y1lak
yl1al
yla8m
y5la1x
y1le
y1lo
y5lu
y8m1n8
y2m1p2
y3mu
y1na
yno2d
yn1t
y1on.
y1o4p
y5ou
y1p2o1
y1pr6
y8ps
y1r
yr2i3e
y2r1r2
y1si
y2s5iat
ys8ty1
y1t
y3w
y1z
yä8m
z5a6b
za1b5l8
8za6d
1zah
za5is
4z3ak
6z1am
zan1ge
5zange.
8z1an5l6
2z1a1ra
6z5as
z5auf
3zaun
2z1b
6z1c
6z1d
1ze
ze1d
ze1di
ze4di1k
ze1f
4z3e2ff
8zein
zei4ta
zei1te
zei8te2r1s
ze6la
ze1le
ze8lec
ze2l1t
zel8th
4ze2mp
zen1ge
6z5engel
zen1zi
zen8zin
ze8r1g
8zer1gä
z2e1r8i
ze1ro
ze2r1s8
ze2r1t
zerta8
zer8tab
zer8tag
8zerz
ze8s1te
zeu6gr4
2z1ex
2z1f8
z1g
4z1h
1zi
zi1en
zi5es.
4z3i2mp
zi1na
6z5in1f
6z5in1ni
zi6ns
zin1se
zin6s5er
zin1su
8zinsuf
zist5r6
zi5th
zi1tr6
6z1j
2z1k
2z1l
2z1m
6z1n
1zo
z8o1g
zo6gl
4z3oh
zo1on
zo2rn
zor6na8
4z1p
z5q
6z1r
2z1s8
2z1t
z4t3e2n1d
z4t3hei
z8thi
1zu
zu3al
zu1b4
zu1f2
6z5u6hr
zu1n2a
zu1ne
8zunem
zun1f8
8zungl
zu1o
zup8fi
zu1s8
zu1z
2z1v
zw8
z1wal
5zwec2k
zwei3s
z1wel
z1wer
z6we8r1g
8z5wes
1zwi
zwi1s
6z1wo
1zy
2z1z
zz8a
z1zi
zzi1s
1zä
1zö
6z1öl.
zö1le
1zü
2z1ü2b
ä1a6
äb1l8
äc8h
ä1che
ä3chi
ä2chs
äch8sc
äch8sp2
ä5chu
äc2k
äc1k5a
äd1a
ä1de
äd5era
ä1di
ä6d5ia
ä1e
ä5fa
äf1l
ä2ft
äf2t6s
äg1h
äg3le
ägn8
ä1gna
ä6g5nan
ä2gs
äg5str6
ä1he
ä1hi
äh1le
äh5ne
1ähn5l6
ä6hr
äh1re
äh5ri
äh1ru
ä1hu
äh1w
6äi
ä1isc
äisc8h
ä6i1sche
ä5i2s1m
ä5j
ä1k
ä8l1c
ä1le
ä8lei
ä2ls
äl1sc
älsc8h
äl6schl6
ä1mi
ämi1e
äm8n8
ä2m8s
ä5na
ä2n1d
än1de
5änd2e1ru
ä1ne
äne5i8
äng3l
änk5l8
ä1no
ä6ns
än6s5c
ä1pa
äp6s5c
3äq
är1c
ä1re
äre8m
ä8r1g
är1ge
5ärge2rn
är6gl
ä1ri
ä6r1m
är1me
3ärmel
ä1ro
ä2r1t
är2t6s5
ä1ru
är2z1t
3ärz2t1l
ä5rö
äsc8h
ä1sche
ä6s5chen
ä1se
äse6n8s
ä2s1th
äta8b
ä1te
ät2e1ri4
äter5it
ä6thy
ä1ti
3ä2t1k2
ä1to
ä2ts
ätsc8h
ät8schl6
äts1p2
ä5tu
äub1l8
äu1e
1äug
äu8ga
ä6u5i
ä1um.
ä1us.
1äuß
ä1z
ö1b
öc8h
ö1che
ö5chi
ö2chs
öchs1te
öch8s2tei
öch8str6
ö2cht6
ö1de
5ö6dem
ö2ff
5öf2f1n
ö1he
öh1l8
ö6hr
öh1re
ö1hu
ö1is
ö1ke
1ö2k2o
1öl.
ö6l1k
öl6k5l8
ö6l1p
öl8pl8
ö1mu
ö5na
ö1ni
öni2g6s3
ö1no
ö5o6t
öpf3l
öp6s5c
ö1re
ö8r1g
ör8g1li
ö1ri
ö2r1t
ör8tr6
ö1ru
ös1te
5öste2rr
ö1te
ö5th
ö1ti
ö1tu
ö1v
ö1w
öwe8
ö2z
ü1b6e2
3ü4ber1
üb1l8
ü1b1r
5ü2bu
üc8h
ü1che
ü1chi
ü8ch3l6
ü2chs
üch6s5c
ü8c2k
üc1k1a
ück5e2r1s
üd1a2
ü1de
ü6deu
ü1di
üdi8t
ü2d1o4
ü2d5s6
ü1ge
üge4l5a
üg1l
üh5a
ü1he
ü8heh
ü6h5e6rk
üh1le
ü6hr
üh1re
üh1ru
ü1hu
üh1w
ü3k
ü1le
ü6ll
ül4l5a
ül8lo
ü6l1p
ül4ps
ü2ls
ül6s5c
ü1lu
ü2n1d
ün8da
ün1f
ün1fe
ün8fei
ünk5l8
ün8za
ün6zw8
ü5pi
ü1re
ü8rei
ür1f
ür8fl
ür8fr6
ü8r1g
ür1ge
ür8geng
ü1ri
ü1ro
ü2r1s
ür8sta
ü1ru
ü1se
üse8n
ü8sta
üs1te
ü8stes
ü3ta
ü1te
ü1ti
ü2t1t
üt8tr6
ü1tu
ü2tz
üt1ze
üt8zei
ü1v
ß1a8
5ßa.
ß8as
ß1b8
ß1c
ß1d
1ße
ß5ec
8ße8g
8ße8h
2ß1ei
8ßem
ß1f8
ß1g
ß1h
1ßi
ß1k
ß1l
ß1m
ß1n
ß1o
ß1p8
ß5q
ß1r
ß1s2
ßst8
ß1ta
ß1te
ßt3hei
ß1ti
ß5to
ß1tr6
1ßu8
6ß5um
ß1v
ß1w
ß1z
2s1ta.
i1sta
i2s1tal
2s1ta1ni
2s1tan.
fe2s1ta
nd1st
nd2s1te
ve2s1te
3s2tec
stec8h
4s5t8e2ch3n6
3s2teg
3s2teh
3s2tein
3s2teig
3s2te2if
3s2te6ll
3s2telz
a4s3tel
3s2te2m1m
3s2te2mp
ss1te
s3s2ter
t3s2te2rn
3s2teu1e
6s4t3eu1ro
bs2ti
te2s3ti
ve2s1ti
3s2tic
3s2tie1b
3s2tieg
3s2t2if
3s2t2il
3s2tim
3s2tink
3s2ti1tu
a2s1to
gu2s1to
ku2s1to
i1sto
i2s1tol
i2s1tor
ve2s1to
2s1tung
2s7tus
o1stu
o2s1tul
aus3s4
ens3s4
gs3s4
.mis2s1
s2s1b8
s1sche
s2s3chen
s2s3d
s2s5ec
2s2s1ei
s2s3f2
s2s3g2
s2s3h
s2s3k2
s2s3l
s2s3m
s2s3n
s2s3p8
s2s5q
s2s3r
s2s3s2
sss2t8
as2s3te
is2s3te
us2s3te
üs2s3te
s2sth
s2st3hei
s2s3ti
s2s1to
s2s1tr6
s1su
6ss5um
s2s3v
s2s3w
s2s3z
1cker.
1cke2r1t
c1ka
1cka1d
1cke.
1ckel
1cken
4ck1ent
1cke1re
1cke2rn
1ck2e1ru
1ckie
1ckig
c1ku
1ckun
ta8s7ta7tur
ta1sta
tast6a1tu
.fli7ck8en7tep7pic8h
.f1li
.f2lic2k
.fli1cken
.fli4ck1ent
.flicken1te
.flicken5tep1pi
.mitt7wo8ch7a8be2n1d
.3mi2t1t
.mit2t1w
.mittwo1c
.mittwoc8h
.mittwocha1be
.ja7cken.
.jac2k
.ja1cken
.ja7cken7ta7sche.
.ja4ck1ent
.jacken1ta
.jackenta1sc
.jackentasc8h
.jackenta1sche
.let7s8cho.
.le2t1s
.letsc8h
.let1scho
.men8s7tru7a7ti7on
.1me
.me6ns
.men1str6
.menstru2a1ti
.menstruat2io
ni7ve8au7st8a7bi7li7tät.
n2i1v
ni1ve
nive1aus
niveau4sta
niveau4st3a4b
niveausta1bi
niveaustab2il
niveaustabi1li
niveaustabili1tä
niveaustabilität2
.ur7in8stin2k1t
.u1ri
.ur5i6ns
.u4rinst
.urins1ti
.urin3s2tink
.wach8s8tu7be
.wac8h
.wa2chs
.wach1stu
.stau8be1cken
.1sta
.stau1be
.staubec2k
.stau8b7ent7wick7lung
.stauben2t1w
.staub5entwic
.staubentwic2k
.staubentwick3l8
.staubentwick1lun

